"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from defoldsdk.ddf import ddf_extensions_pb2 as ddf_dot_ddf__extensions__pb2
from defoldsdk.ddf import ddf_math_pb2 as ddf_dot_ddf__math__pb2
from defoldsdk.script import lua_source_ddf_pb2 as script_dot_lua__source__ddf__pb2
from defoldsdk.gameobject import properties_ddf_pb2 as gameobject_dot_properties__ddf__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18gameobject/lua_ddf.proto\x12\x08dmLuaDDF\x1a\x18ddf/ddf_extensions.proto\x1a\x12ddf/ddf_math.proto\x1a\x1bscript/lua_source_ddf.proto\x1a\x1fgameobject/properties_ddf.proto"\xb7\x01\n\tLuaModule\x12#\n\x06source\x18\x01 \x02(\x0b2\x13.dmLuaDDF.LuaSource\x12\x0f\n\x07modules\x18\x02 \x03(\t\x12\x17\n\tresources\x18\x03 \x03(\tB\x04\xa0\xbb\x18\x01\x129\n\nproperties\x18\x04 \x01(\x0b2%.dmPropertiesDDF.PropertyDeclarations\x12 \n\x12property_resources\x18\x05 \x03(\tB\x04\xa0\xbb\x18\x01B\x1b\n\x14com.dynamo.lua.protoB\x03Lua')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gameobject.lua_ddf_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'\n\x14com.dynamo.lua.protoB\x03Lua'
    _LUAMODULE.fields_by_name['resources']._options = None
    _LUAMODULE.fields_by_name['resources']._serialized_options = b'\xa0\xbb\x18\x01'
    _LUAMODULE.fields_by_name['property_resources']._options = None
    _LUAMODULE.fields_by_name['property_resources']._serialized_options = b'\xa0\xbb\x18\x01'
    _LUAMODULE._serialized_start = 147
    _LUAMODULE._serialized_end = 330



"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from defoldsdk.ddf import ddf_extensions_pb2 as ddf_dot_ddf__extensions__pb2
from defoldsdk.ddf import ddf_math_pb2 as ddf_dot_ddf__math__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18gamesys/camera_ddf.proto\x12\x0cdmGamesysDDF\x1a\x18ddf/ddf_extensions.proto\x1a\x12ddf/ddf_math.proto"\xf8\x01\n\nCameraDesc\x12\x14\n\x0caspect_ratio\x18\x01 \x02(\x02\x12\x0b\n\x03fov\x18\x02 \x02(\x02\x12\x0e\n\x06near_z\x18\x03 \x02(\x02\x12\r\n\x05far_z\x18\x04 \x02(\x02\x12\x1c\n\x11auto_aspect_ratio\x18\x05 \x01(\r:\x010\x12"\n\x17orthographic_projection\x18\x06 \x01(\r:\x010\x12\x1c\n\x11orthographic_zoom\x18\x07 \x01(\x02:\x011\x12H\n\x11orthographic_mode\x18\x08 \x01(\x0e2\x1b.dmGamesysDDF.OrthoZoomMode:\x10ORTHO_MODE_FIXED"\xd9\x01\n\tSetCamera\x12\x14\n\x0caspect_ratio\x18\x01 \x02(\x02\x12\x0b\n\x03fov\x18\x02 \x02(\x02\x12\x0e\n\x06near_z\x18\x03 \x02(\x02\x12\r\n\x05far_z\x18\x04 \x02(\x02\x12"\n\x17orthographic_projection\x18\x05 \x01(\r:\x010\x12\x1c\n\x11orthographic_zoom\x18\x06 \x01(\x02:\x011\x12H\n\x11orthographic_mode\x18\x07 \x01(\x0e2\x1b.dmGamesysDDF.OrthoZoomMode:\x10ORTHO_MODE_FIXED"\x14\n\x12AcquireCameraFocus"\x14\n\x12ReleaseCameraFocus*\x82\x01\n\rOrthoZoomMode\x12\x1f\n\x10ORTHO_MODE_FIXED\x10\x00\x1a\t\xc2\xc1\x18\x05Fixed\x12%\n\x13ORTHO_MODE_AUTO_FIT\x10\x01\x1a\x0c\xc2\xc1\x18\x08Auto Fit\x12)\n\x15ORTHO_MODE_AUTO_COVER\x10\x02\x1a\x0e\xc2\xc1\x18\nAuto CoverB"\n\x18com.dynamo.gamesys.protoB\x06Camera')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gamesys.camera_ddf_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'\n\x18com.dynamo.gamesys.protoB\x06Camera'
    _ORTHOZOOMMODE.values_by_name['ORTHO_MODE_FIXED']._options = None
    _ORTHOZOOMMODE.values_by_name['ORTHO_MODE_FIXED']._serialized_options = b'\xc2\xc1\x18\x05Fixed'
    _ORTHOZOOMMODE.values_by_name['ORTHO_MODE_AUTO_FIT']._options = None
    _ORTHOZOOMMODE.values_by_name['ORTHO_MODE_AUTO_FIT']._serialized_options = b'\xc2\xc1\x18\x08Auto Fit'
    _ORTHOZOOMMODE.values_by_name['ORTHO_MODE_AUTO_COVER']._options = None
    _ORTHOZOOMMODE.values_by_name['ORTHO_MODE_AUTO_COVER']._serialized_options = b'\xc2\xc1\x18\nAuto Cover'
    _ORTHOZOOMMODE._serialized_start = 604
    _ORTHOZOOMMODE._serialized_end = 734
    _CAMERADESC._serialized_start = 89
    _CAMERADESC._serialized_end = 337
    _SETCAMERA._serialized_start = 340
    _SETCAMERA._serialized_end = 557
    _ACQUIRECAMERAFOCUS._serialized_start = 559
    _ACQUIRECAMERAFOCUS._serialized_end = 579
    _RELEASECAMERAFOCUS._serialized_start = 581
    _RELEASECAMERAFOCUS._serialized_end = 601



"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from defoldsdk.ddf import ddf_extensions_pb2 as ddf_dot_ddf__extensions__pb2
from defoldsdk.ddf import ddf_math_pb2 as ddf_dot_ddf__math__pb2
from defoldsdk.graphics import graphics_ddf_pb2 as graphics_dot_graphics__ddf__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18gamesys/sprite_ddf.proto\x12\x0fdmGameSystemDDF\x1a\x18ddf/ddf_extensions.proto\x1a\x12ddf/ddf_math.proto\x1a\x1bgraphics/graphics_ddf.proto"7\n\rSpriteTexture\x12\x0f\n\x07sampler\x18\x01 \x02(\t\x12\x15\n\x07texture\x18\x02 \x02(\tB\x04\xa0\xbb\x18\x01"\xf6\x05\n\nSpriteDesc\x12\x16\n\x08tile_set\x18\x01 \x01(\tB\x04\xa0\xbb\x18\x01\x12\x19\n\x11default_animation\x18\x02 \x02(\t\x12;\n\x08material\x18\x03 \x01(\t:#/builtins/materials/sprite.materialB\x04\xa0\xbb\x18\x01\x12K\n\nblend_mode\x18\x04 \x01(\x0e2%.dmGameSystemDDF.SpriteDesc.BlendMode:\x10BLEND_MODE_ALPHA\x12\x1f\n\x06slice9\x18\x05 \x01(\x0b2\x0f.dmMath.Vector4\x12\x1d\n\x04size\x18\x06 \x01(\x0b2\x0f.dmMath.Vector4\x12G\n\tsize_mode\x18\x07 \x01(\x0e2$.dmGameSystemDDF.SpriteDesc.SizeMode:\x0eSIZE_MODE_AUTO\x12\x11\n\x06offset\x18\x08 \x01(\x02:\x010\x12\x18\n\rplayback_rate\x18\t \x01(\x02:\x011\x12/\n\nattributes\x18\n \x03(\x0b2\x1b.dmGraphics.VertexAttribute\x120\n\x08textures\x18\x0b \x03(\x0b2\x1e.dmGameSystemDDF.SpriteTexture"\xc5\x01\n\tBlendMode\x12\x1f\n\x10BLEND_MODE_ALPHA\x10\x00\x1a\t\xc2\xc1\x18\x05Alpha\x12\x1b\n\x0eBLEND_MODE_ADD\x10\x01\x1a\x07\xc2\xc1\x18\x03Add\x124\n\x14BLEND_MODE_ADD_ALPHA\x10\x02\x1a\x1a\xc2\xc1\x18\x16Add Alpha (Deprecated)\x12!\n\x0fBLEND_MODE_MULT\x10\x03\x1a\x0c\xc2\xc1\x18\x08Multiply\x12!\n\x11BLEND_MODE_SCREEN\x10\x04\x1a\n\xc2\xc1\x18\x06Screen"J\n\x08SizeMode\x12 \n\x10SIZE_MODE_MANUAL\x10\x00\x1a\n\xc2\xc1\x18\x06Manual\x12\x1c\n\x0eSIZE_MODE_AUTO\x10\x01\x1a\x08\xc2\xc1\x18\x04Auto"H\n\rPlayAnimation\x12\n\n\x02id\x18\x01 \x02(\x04\x12\x11\n\x06offset\x18\x02 \x01(\x02:\x010\x12\x18\n\rplayback_rate\x18\x03 \x01(\x02:\x011"1\n\rAnimationDone\x12\x14\n\x0ccurrent_tile\x18\x01 \x02(\r\x12\n\n\x02id\x18\x02 \x02(\x04"!\n\x11SetFlipHorizontal\x12\x0c\n\x04flip\x18\x01 \x02(\r"\x1f\n\x0fSetFlipVertical\x12\x0c\n\x04flip\x18\x01 \x02(\rB"\n\x18com.dynamo.gamesys.protoB\x06Sprite')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gamesys.sprite_ddf_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'\n\x18com.dynamo.gamesys.protoB\x06Sprite'
    _SPRITETEXTURE.fields_by_name['texture']._options = None
    _SPRITETEXTURE.fields_by_name['texture']._serialized_options = b'\xa0\xbb\x18\x01'
    _SPRITEDESC_BLENDMODE.values_by_name['BLEND_MODE_ALPHA']._options = None
    _SPRITEDESC_BLENDMODE.values_by_name['BLEND_MODE_ALPHA']._serialized_options = b'\xc2\xc1\x18\x05Alpha'
    _SPRITEDESC_BLENDMODE.values_by_name['BLEND_MODE_ADD']._options = None
    _SPRITEDESC_BLENDMODE.values_by_name['BLEND_MODE_ADD']._serialized_options = b'\xc2\xc1\x18\x03Add'
    _SPRITEDESC_BLENDMODE.values_by_name['BLEND_MODE_ADD_ALPHA']._options = None
    _SPRITEDESC_BLENDMODE.values_by_name['BLEND_MODE_ADD_ALPHA']._serialized_options = b'\xc2\xc1\x18\x16Add Alpha (Deprecated)'
    _SPRITEDESC_BLENDMODE.values_by_name['BLEND_MODE_MULT']._options = None
    _SPRITEDESC_BLENDMODE.values_by_name['BLEND_MODE_MULT']._serialized_options = b'\xc2\xc1\x18\x08Multiply'
    _SPRITEDESC_BLENDMODE.values_by_name['BLEND_MODE_SCREEN']._options = None
    _SPRITEDESC_BLENDMODE.values_by_name['BLEND_MODE_SCREEN']._serialized_options = b'\xc2\xc1\x18\x06Screen'
    _SPRITEDESC_SIZEMODE.values_by_name['SIZE_MODE_MANUAL']._options = None
    _SPRITEDESC_SIZEMODE.values_by_name['SIZE_MODE_MANUAL']._serialized_options = b'\xc2\xc1\x18\x06Manual'
    _SPRITEDESC_SIZEMODE.values_by_name['SIZE_MODE_AUTO']._options = None
    _SPRITEDESC_SIZEMODE.values_by_name['SIZE_MODE_AUTO']._serialized_options = b'\xc2\xc1\x18\x04Auto'
    _SPRITEDESC.fields_by_name['tile_set']._options = None
    _SPRITEDESC.fields_by_name['tile_set']._serialized_options = b'\xa0\xbb\x18\x01'
    _SPRITEDESC.fields_by_name['material']._options = None
    _SPRITEDESC.fields_by_name['material']._serialized_options = b'\xa0\xbb\x18\x01'
    _SPRITETEXTURE._serialized_start = 120
    _SPRITETEXTURE._serialized_end = 175
    _SPRITEDESC._serialized_start = 178
    _SPRITEDESC._serialized_end = 936
    _SPRITEDESC_BLENDMODE._serialized_start = 663
    _SPRITEDESC_BLENDMODE._serialized_end = 860
    _SPRITEDESC_SIZEMODE._serialized_start = 862
    _SPRITEDESC_SIZEMODE._serialized_end = 936
    _PLAYANIMATION._serialized_start = 938
    _PLAYANIMATION._serialized_end = 1010
    _ANIMATIONDONE._serialized_start = 1012
    _ANIMATIONDONE._serialized_end = 1061
    _SETFLIPHORIZONTAL._serialized_start = 1063
    _SETFLIPHORIZONTAL._serialized_end = 1096
    _SETFLIPVERTICAL._serialized_start = 1098
    _SETFLIPVERTICAL._serialized_end = 1129



"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from defoldsdk.ddf import ddf_extensions_pb2 as ddf_dot_ddf__extensions__pb2
from defoldsdk.ddf import ddf_math_pb2 as ddf_dot_ddf__math__pb2
from defoldsdk.graphics import graphics_ddf_pb2 as graphics_dot_graphics__ddf__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17gamesys/model_ddf.proto\x12\ndmModelDDF\x1a\x18ddf/ddf_extensions.proto\x1a\x12ddf/ddf_math.proto\x1a\x1bgraphics/graphics_ddf.proto"1\n\x07Texture\x12\x0f\n\x07sampler\x18\x01 \x02(\t\x12\x15\n\x07texture\x18\x02 \x02(\tB\x04\xa0\xbb\x18\x01"\x88\x01\n\x08Material\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x16\n\x08material\x18\x02 \x02(\tB\x04\xa0\xbb\x18\x01\x12%\n\x08textures\x18\x03 \x03(\x0b2\x13.dmModelDDF.Texture\x12/\n\nattributes\x18\x04 \x03(\x0b2\x1b.dmGraphics.VertexAttribute"\xf2\x01\n\tModelDesc\x12\x12\n\x04mesh\x18\x02 \x02(\tB\x04\xa0\xbb\x18\x01\x12\x16\n\x08material\x18\x03 \x01(\tB\x04\xa0\xbb\x18\x01\x12\x16\n\x08textures\x18\x04 \x03(\tB\x04\xa0\xbb\x18\x01\x12\x16\n\x08skeleton\x18\x05 \x01(\tB\x04\xa0\xbb\x18\x01\x12\x18\n\nanimations\x18\x06 \x01(\tB\x04\xa0\xbb\x18\x01\x12\x19\n\x11default_animation\x18\x07 \x01(\t\x12\x0c\n\x04name\x18\n \x01(\t\x12\'\n\tmaterials\x18\x0b \x03(\x0b2\x14.dmModelDDF.Material\x12\x1d\n\x0fcreate_go_bones\x18\x0c \x01(\x08:\x04true"}\n\x05Model\x12\x17\n\trig_scene\x18\x01 \x02(\tB\x04\xa0\xbb\x18\x01\x12\x19\n\x11default_animation\x18\x02 \x01(\t\x12\'\n\tmaterials\x18\x03 \x03(\x0b2\x14.dmModelDDF.Material\x12\x17\n\x0fcreate_go_bones\x18\x04 \x01(\x08""\n\rResetConstant\x12\x11\n\tname_hash\x18\x01 \x02(\x04"8\n\nSetTexture\x12\x14\n\x0ctexture_hash\x18\x01 \x02(\x04\x12\x14\n\x0ctexture_unit\x18\x02 \x02(\r"\x84\x01\n\x12ModelPlayAnimation\x12\x14\n\x0canimation_id\x18\x01 \x02(\x04\x12\x10\n\x08playback\x18\x02 \x02(\r\x12\x19\n\x0eblend_duration\x18\x03 \x01(\x02:\x010\x12\x11\n\x06offset\x18\x04 \x01(\x02:\x010\x12\x18\n\rplayback_rate\x18\x05 \x01(\x02:\x011"\x16\n\x14ModelCancelAnimation"<\n\x12ModelAnimationDone\x12\x14\n\x0canimation_id\x18\x01 \x02(\x04\x12\x10\n\x08playback\x18\x02 \x02(\rB&\n\x18com.dynamo.gamesys.protoB\nModelProto')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gamesys.model_ddf_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'\n\x18com.dynamo.gamesys.protoB\nModelProto'
    _TEXTURE.fields_by_name['texture']._options = None
    _TEXTURE.fields_by_name['texture']._serialized_options = b'\xa0\xbb\x18\x01'
    _MATERIAL.fields_by_name['material']._options = None
    _MATERIAL.fields_by_name['material']._serialized_options = b'\xa0\xbb\x18\x01'
    _MODELDESC.fields_by_name['mesh']._options = None
    _MODELDESC.fields_by_name['mesh']._serialized_options = b'\xa0\xbb\x18\x01'
    _MODELDESC.fields_by_name['material']._options = None
    _MODELDESC.fields_by_name['material']._serialized_options = b'\xa0\xbb\x18\x01'
    _MODELDESC.fields_by_name['textures']._options = None
    _MODELDESC.fields_by_name['textures']._serialized_options = b'\xa0\xbb\x18\x01'
    _MODELDESC.fields_by_name['skeleton']._options = None
    _MODELDESC.fields_by_name['skeleton']._serialized_options = b'\xa0\xbb\x18\x01'
    _MODELDESC.fields_by_name['animations']._options = None
    _MODELDESC.fields_by_name['animations']._serialized_options = b'\xa0\xbb\x18\x01'
    _MODEL.fields_by_name['rig_scene']._options = None
    _MODEL.fields_by_name['rig_scene']._serialized_options = b'\xa0\xbb\x18\x01'
    _TEXTURE._serialized_start = 114
    _TEXTURE._serialized_end = 163
    _MATERIAL._serialized_start = 166
    _MATERIAL._serialized_end = 302
    _MODELDESC._serialized_start = 305
    _MODELDESC._serialized_end = 547
    _MODEL._serialized_start = 549
    _MODEL._serialized_end = 674
    _RESETCONSTANT._serialized_start = 676
    _RESETCONSTANT._serialized_end = 710
    _SETTEXTURE._serialized_start = 712
    _SETTEXTURE._serialized_end = 768
    _MODELPLAYANIMATION._serialized_start = 771
    _MODELPLAYANIMATION._serialized_end = 903
    _MODELCANCELANIMATION._serialized_start = 905
    _MODELCANCELANIMATION._serialized_end = 927
    _MODELANIMATIONDONE._serialized_start = 929
    _MODELANIMATIONDONE._serialized_end = 989



"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from defoldsdk.ddf import ddf_extensions_pb2 as ddf_dot_ddf__extensions__pb2
from defoldsdk.ddf import ddf_math_pb2 as ddf_dot_ddf__math__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17gamesys/label_ddf.proto\x12\x0fdmGameSystemDDF\x1a\x18ddf/ddf_extensions.proto\x1a\x12ddf/ddf_math.proto"\xd1\x06\n\tLabelDesc\x12\x1d\n\x04size\x18\x01 \x02(\x0b2\x0f.dmMath.Vector4\x12!\n\x05scale\x18\x02 \x01(\x0b2\x12.dmMath.Vector4One\x12!\n\x05color\x18\x03 \x01(\x0b2\x12.dmMath.Vector4One\x12$\n\x07outline\x18\x04 \x01(\x0b2\x13.dmMath.Vector4WOne\x12#\n\x06shadow\x18\x05 \x01(\x0b2\x13.dmMath.Vector4WOne\x12\x12\n\x07leading\x18\x06 \x01(\x02:\x011\x12\x10\n\x08tracking\x18\x07 \x01(\x02\x12=\n\x05pivot\x18\x08 \x01(\x0e2 .dmGameSystemDDF.LabelDesc.Pivot:\x0cPIVOT_CENTER\x12J\n\nblend_mode\x18\t \x01(\x0e2$.dmGameSystemDDF.LabelDesc.BlendMode:\x10BLEND_MODE_ALPHA\x12\x19\n\nline_break\x18\n \x01(\x08:\x05false\x12\x0c\n\x04text\x18\x0b \x01(\t\x12\x12\n\x04font\x18\x0c \x02(\tB\x04\xa0\xbb\x18\x01\x12\x16\n\x08material\x18\r \x02(\tB\x04\xa0\xbb\x18\x01"\x8f\x01\n\tBlendMode\x12\x1f\n\x10BLEND_MODE_ALPHA\x10\x00\x1a\t\xc2\xc1\x18\x05Alpha\x12\x1b\n\x0eBLEND_MODE_ADD\x10\x01\x1a\x07\xc2\xc1\x18\x03Add\x12!\n\x0fBLEND_MODE_MULT\x10\x03\x1a\x0c\xc2\xc1\x18\x08Multiply\x12!\n\x11BLEND_MODE_SCREEN\x10\x04\x1a\n\xc2\xc1\x18\x06Screen"\xfb\x01\n\x05Pivot\x12\x1c\n\x0cPIVOT_CENTER\x10\x00\x1a\n\xc2\xc1\x18\x06Center\x12\x16\n\x07PIVOT_N\x10\x01\x1a\t\xc2\xc1\x18\x05North\x12\x1c\n\x08PIVOT_NE\x10\x02\x1a\x0e\xc2\xc1\x18\nNorth East\x12\x15\n\x07PIVOT_E\x10\x03\x1a\x08\xc2\xc1\x18\x04East\x12\x1c\n\x08PIVOT_SE\x10\x04\x1a\x0e\xc2\xc1\x18\nSouth East\x12\x16\n\x07PIVOT_S\x10\x05\x1a\t\xc2\xc1\x18\x05South\x12\x1c\n\x08PIVOT_SW\x10\x06\x1a\x0e\xc2\xc1\x18\nSouth West\x12\x15\n\x07PIVOT_W\x10\x07\x1a\x08\xc2\xc1\x18\x04West\x12\x1c\n\x08PIVOT_NW\x10\x08\x1a\x0e\xc2\xc1\x18\nNorth West"\x17\n\x07SetText\x12\x0c\n\x04text\x18\x01 \x02(\tB!\n\x18com.dynamo.gamesys.protoB\x05Label')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gamesys.label_ddf_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'\n\x18com.dynamo.gamesys.protoB\x05Label'
    _LABELDESC_BLENDMODE.values_by_name['BLEND_MODE_ALPHA']._options = None
    _LABELDESC_BLENDMODE.values_by_name['BLEND_MODE_ALPHA']._serialized_options = b'\xc2\xc1\x18\x05Alpha'
    _LABELDESC_BLENDMODE.values_by_name['BLEND_MODE_ADD']._options = None
    _LABELDESC_BLENDMODE.values_by_name['BLEND_MODE_ADD']._serialized_options = b'\xc2\xc1\x18\x03Add'
    _LABELDESC_BLENDMODE.values_by_name['BLEND_MODE_MULT']._options = None
    _LABELDESC_BLENDMODE.values_by_name['BLEND_MODE_MULT']._serialized_options = b'\xc2\xc1\x18\x08Multiply'
    _LABELDESC_BLENDMODE.values_by_name['BLEND_MODE_SCREEN']._options = None
    _LABELDESC_BLENDMODE.values_by_name['BLEND_MODE_SCREEN']._serialized_options = b'\xc2\xc1\x18\x06Screen'
    _LABELDESC_PIVOT.values_by_name['PIVOT_CENTER']._options = None
    _LABELDESC_PIVOT.values_by_name['PIVOT_CENTER']._serialized_options = b'\xc2\xc1\x18\x06Center'
    _LABELDESC_PIVOT.values_by_name['PIVOT_N']._options = None
    _LABELDESC_PIVOT.values_by_name['PIVOT_N']._serialized_options = b'\xc2\xc1\x18\x05North'
    _LABELDESC_PIVOT.values_by_name['PIVOT_NE']._options = None
    _LABELDESC_PIVOT.values_by_name['PIVOT_NE']._serialized_options = b'\xc2\xc1\x18\nNorth East'
    _LABELDESC_PIVOT.values_by_name['PIVOT_E']._options = None
    _LABELDESC_PIVOT.values_by_name['PIVOT_E']._serialized_options = b'\xc2\xc1\x18\x04East'
    _LABELDESC_PIVOT.values_by_name['PIVOT_SE']._options = None
    _LABELDESC_PIVOT.values_by_name['PIVOT_SE']._serialized_options = b'\xc2\xc1\x18\nSouth East'
    _LABELDESC_PIVOT.values_by_name['PIVOT_S']._options = None
    _LABELDESC_PIVOT.values_by_name['PIVOT_S']._serialized_options = b'\xc2\xc1\x18\x05South'
    _LABELDESC_PIVOT.values_by_name['PIVOT_SW']._options = None
    _LABELDESC_PIVOT.values_by_name['PIVOT_SW']._serialized_options = b'\xc2\xc1\x18\nSouth West'
    _LABELDESC_PIVOT.values_by_name['PIVOT_W']._options = None
    _LABELDESC_PIVOT.values_by_name['PIVOT_W']._serialized_options = b'\xc2\xc1\x18\x04West'
    _LABELDESC_PIVOT.values_by_name['PIVOT_NW']._options = None
    _LABELDESC_PIVOT.values_by_name['PIVOT_NW']._serialized_options = b'\xc2\xc1\x18\nNorth West'
    _LABELDESC.fields_by_name['font']._options = None
    _LABELDESC.fields_by_name['font']._serialized_options = b'\xa0\xbb\x18\x01'
    _LABELDESC.fields_by_name['material']._options = None
    _LABELDESC.fields_by_name['material']._serialized_options = b'\xa0\xbb\x18\x01'
    _LABELDESC._serialized_start = 91
    _LABELDESC._serialized_end = 940
    _LABELDESC_BLENDMODE._serialized_start = 543
    _LABELDESC_BLENDMODE._serialized_end = 686
    _LABELDESC_PIVOT._serialized_start = 689
    _LABELDESC_PIVOT._serialized_end = 940
    _SETTEXT._serialized_start = 942
    _SETTEXT._serialized_end = 965



"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from defoldsdk.ddf import ddf_extensions_pb2 as ddf_dot_ddf__extensions__pb2
from defoldsdk.ddf import ddf_math_pb2 as ddf_dot_ddf__math__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fgameobject/properties_ddf.proto\x12\x0fdmPropertiesDDF\x1a\x18ddf/ddf_extensions.proto\x1a\x12ddf/ddf_math.proto"W\n\x18PropertyDeclarationEntry\x12\x0b\n\x03key\x18\x01 \x02(\t\x12\n\n\x02id\x18\x02 \x02(\x04\x12\r\n\x05index\x18\x03 \x02(\r\x12\x13\n\x0belement_ids\x18\x04 \x03(\x04"\xa6\x04\n\x14PropertyDeclarations\x12A\n\x0enumber_entries\x18\x01 \x03(\x0b2).dmPropertiesDDF.PropertyDeclarationEntry\x12?\n\x0chash_entries\x18\x02 \x03(\x0b2).dmPropertiesDDF.PropertyDeclarationEntry\x12>\n\x0burl_entries\x18\x03 \x03(\x0b2).dmPropertiesDDF.PropertyDeclarationEntry\x12B\n\x0fvector3_entries\x18\x04 \x03(\x0b2).dmPropertiesDDF.PropertyDeclarationEntry\x12B\n\x0fvector4_entries\x18\x05 \x03(\x0b2).dmPropertiesDDF.PropertyDeclarationEntry\x12?\n\x0cquat_entries\x18\x06 \x03(\x0b2).dmPropertiesDDF.PropertyDeclarationEntry\x12?\n\x0cbool_entries\x18\x07 \x03(\x0b2).dmPropertiesDDF.PropertyDeclarationEntry\x12\x14\n\x0cfloat_values\x18\x08 \x03(\x02\x12\x13\n\x0bhash_values\x18\t \x03(\x04\x12\x15\n\rstring_values\x18\n \x03(\tB.\n\x1bcom.dynamo.properties.protoB\x0fPropertiesProto')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gameobject.properties_ddf_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'\n\x1bcom.dynamo.properties.protoB\x0fPropertiesProto'
    _PROPERTYDECLARATIONENTRY._serialized_start = 98
    _PROPERTYDECLARATIONENTRY._serialized_end = 185
    _PROPERTYDECLARATIONS._serialized_start = 188
    _PROPERTYDECLARATIONS._serialized_end = 738



"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from defoldsdk.ddf import ddf_extensions_pb2 as ddf_dot_ddf__extensions__pb2
from defoldsdk.ddf import ddf_math_pb2 as ddf_dot_ddf__math__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14script/sys_ddf.proto\x12\x0bdmSystemDDF\x1a\x18ddf/ddf_extensions.proto\x1a\x12ddf/ddf_math.proto"\x14\n\x04Exit\x12\x0c\n\x04code\x18\x01 \x02(\x05"\x0f\n\rToggleProfile"\x14\n\x12TogglePhysicsDebug"J\n\x0bStartRecord\x12\x11\n\tfile_name\x18\x01 \x02(\t\x12\x17\n\x0cframe_period\x18\x02 \x01(\x05:\x012\x12\x0f\n\x03fps\x18\x03 \x01(\x05:\x0230"\x0c\n\nStopRecord"\\\n\x06Reboot\x12\x0c\n\x04arg1\x18\x01 \x01(\t\x12\x0c\n\x04arg2\x18\x02 \x01(\t\x12\x0c\n\x04arg3\x18\x03 \x01(\t\x12\x0c\n\x04arg4\x18\x04 \x01(\t\x12\x0c\n\x04arg5\x18\x05 \x01(\t\x12\x0c\n\x04arg6\x18\x06 \x01(\t"$\n\x08SetVsync\x12\x18\n\rswap_interval\x18\x01 \x02(\x05:\x011"\'\n\x12SetUpdateFrequency\x12\x11\n\tfrequency\x18\x01 \x02(\x05"\x11\n\x0fResumeRenderingB!\n\x17com.dynamo.system.protoB\x06System')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'script.sys_ddf_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'\n\x17com.dynamo.system.protoB\x06System'
    _EXIT._serialized_start = 83
    _EXIT._serialized_end = 103
    _TOGGLEPROFILE._serialized_start = 105
    _TOGGLEPROFILE._serialized_end = 120
    _TOGGLEPHYSICSDEBUG._serialized_start = 122
    _TOGGLEPHYSICSDEBUG._serialized_end = 142
    _STARTRECORD._serialized_start = 144
    _STARTRECORD._serialized_end = 218
    _STOPRECORD._serialized_start = 220
    _STOPRECORD._serialized_end = 232
    _REBOOT._serialized_start = 234
    _REBOOT._serialized_end = 326
    _SETVSYNC._serialized_start = 328
    _SETVSYNC._serialized_end = 364
    _SETUPDATEFREQUENCY._serialized_start = 366
    _SETUPDATEFREQUENCY._serialized_end = 405
    _RESUMERENDERING._serialized_start = 407
    _RESUMERENDERING._serialized_end = 424



"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from defoldsdk.ddf import ddf_extensions_pb2 as ddf_dot_ddf__extensions__pb2
from defoldsdk.ddf import ddf_math_pb2 as ddf_dot_ddf__math__pb2
from defoldsdk.gamesys import tile_ddf_pb2 as gamesys_dot_tile__ddf__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17gamesys/atlas_ddf.proto\x12\x0fdmGameSystemDDF\x1a\x18ddf/ddf_extensions.proto\x1a\x12ddf/ddf_math.proto\x1a\x16gamesys/tile_ddf.proto"\xa2\x01\n\nAtlasImage\x12\x13\n\x05image\x18\x01 \x02(\tB\x04\xa0\xbb\x18\x01\x12S\n\x10sprite_trim_mode\x18\x02 \x01(\x0e2#.dmGameSystemDDF.SpriteTrimmingMode:\x14SPRITE_TRIM_MODE_OFF\x12\x14\n\x07pivot_x\x18\x03 \x01(\x02:\x030.5\x12\x14\n\x07pivot_y\x18\x04 \x01(\x02:\x030.5"\xd4\x01\n\x0eAtlasAnimation\x12\n\n\x02id\x18\x01 \x02(\t\x12+\n\x06images\x18\x02 \x03(\x0b2\x1b.dmGameSystemDDF.AtlasImage\x12B\n\x08playback\x18\x03 \x01(\x0e2\x19.dmGameSystemDDF.Playback:\x15PLAYBACK_ONCE_FORWARD\x12\x0f\n\x03fps\x18\x04 \x01(\r:\x0230\x12\x1a\n\x0fflip_horizontal\x18\x05 \x01(\r:\x010\x12\x18\n\rflip_vertical\x18\x06 \x01(\r:\x010"\x82\x02\n\x05Atlas\x12+\n\x06images\x18\x01 \x03(\x0b2\x1b.dmGameSystemDDF.AtlasImage\x123\n\nanimations\x18\x02 \x03(\x0b2\x1f.dmGameSystemDDF.AtlasAnimation\x12\x11\n\x06margin\x18\x03 \x01(\r:\x010\x12\x1a\n\x0fextrude_borders\x18\x04 \x01(\r:\x010\x12\x18\n\rinner_padding\x18\x05 \x01(\r:\x010\x12\x19\n\x0emax_page_width\x18\x06 \x01(\r:\x010\x12\x1a\n\x0fmax_page_height\x18\x07 \x01(\r:\x010\x12\x17\n\x0frename_patterns\x18\x08 \x01(\tB&\n\x18com.dynamo.gamesys.protoB\nAtlasProto')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gamesys.atlas_ddf_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'\n\x18com.dynamo.gamesys.protoB\nAtlasProto'
    _ATLASIMAGE.fields_by_name['image']._options = None
    _ATLASIMAGE.fields_by_name['image']._serialized_options = b'\xa0\xbb\x18\x01'
    _ATLASIMAGE._serialized_start = 115
    _ATLASIMAGE._serialized_end = 277
    _ATLASANIMATION._serialized_start = 280
    _ATLASANIMATION._serialized_end = 492
    _ATLAS._serialized_start = 495
    _ATLAS._serialized_end = 753



"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from defoldsdk.ddf import ddf_extensions_pb2 as ddf_dot_ddf__extensions__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12ddf/ddf_math.proto\x12\x06dmMath\x1a\x18ddf/ddf_extensions.proto"U\n\x06Point3\x12\x0c\n\x01x\x18\x01 \x01(\x02:\x010\x12\x0c\n\x01y\x18\x02 \x01(\x02:\x010\x12\x0c\n\x01z\x18\x03 \x01(\x02:\x010\x12\x0c\n\x01d\x18\x04 \x01(\x02:\x010:\x13\x82\xb5\x18\x0fdmVMath::Point3"W\n\x07Vector3\x12\x0c\n\x01x\x18\x01 \x01(\x02:\x010\x12\x0c\n\x01y\x18\x02 \x01(\x02:\x010\x12\x0c\n\x01z\x18\x03 \x01(\x02:\x010\x12\x0c\n\x01d\x18\x04 \x01(\x02:\x010:\x14\x82\xb5\x18\x10dmVMath::Vector3"Z\n\nVector3One\x12\x0c\n\x01x\x18\x01 \x01(\x02:\x011\x12\x0c\n\x01y\x18\x02 \x01(\x02:\x011\x12\x0c\n\x01z\x18\x03 \x01(\x02:\x011\x12\x0c\n\x01d\x18\x04 \x01(\x02:\x011:\x14\x82\xb5\x18\x10dmVMath::Vector3"W\n\x07Vector4\x12\x0c\n\x01x\x18\x01 \x01(\x02:\x010\x12\x0c\n\x01y\x18\x02 \x01(\x02:\x010\x12\x0c\n\x01z\x18\x03 \x01(\x02:\x010\x12\x0c\n\x01w\x18\x04 \x01(\x02:\x010:\x14\x82\xb5\x18\x10dmVMath::Vector4"Z\n\nVector4One\x12\x0c\n\x01x\x18\x01 \x01(\x02:\x011\x12\x0c\n\x01y\x18\x02 \x01(\x02:\x011\x12\x0c\n\x01z\x18\x03 \x01(\x02:\x011\x12\x0c\n\x01w\x18\x04 \x01(\x02:\x011:\x14\x82\xb5\x18\x10dmVMath::Vector4"[\n\x0bVector4WOne\x12\x0c\n\x01x\x18\x01 \x01(\x02:\x010\x12\x0c\n\x01y\x18\x02 \x01(\x02:\x010\x12\x0c\n\x01z\x18\x03 \x01(\x02:\x010\x12\x0c\n\x01w\x18\x04 \x01(\x02:\x011:\x14\x82\xb5\x18\x10dmVMath::Vector4"Q\n\x04Quat\x12\x0c\n\x01x\x18\x01 \x01(\x02:\x010\x12\x0c\n\x01y\x18\x02 \x01(\x02:\x010\x12\x0c\n\x01z\x18\x03 \x01(\x02:\x010\x12\x0c\n\x01w\x18\x04 \x01(\x02:\x011:\x11\x82\xb5\x18\rdmVMath::Quat"\x8d\x01\n\tTransform\x12\x1e\n\x08rotation\x18\x01 \x01(\x0b2\x0c.dmMath.Quat\x12$\n\x0btranslation\x18\x02 \x01(\x0b2\x0f.dmMath.Vector3\x12\x1e\n\x05scale\x18\x03 \x01(\x0b2\x0f.dmMath.Vector3:\x1a\x82\xb5\x18\x16dmTransform::Transform"\x9f\x02\n\x07Matrix4\x12\x0e\n\x03m00\x18\x01 \x01(\x02:\x011\x12\x0e\n\x03m01\x18\x02 \x01(\x02:\x010\x12\x0e\n\x03m02\x18\x03 \x01(\x02:\x010\x12\x0e\n\x03m03\x18\x04 \x01(\x02:\x010\x12\x0e\n\x03m10\x18\x05 \x01(\x02:\x010\x12\x0e\n\x03m11\x18\x06 \x01(\x02:\x011\x12\x0e\n\x03m12\x18\x07 \x01(\x02:\x010\x12\x0e\n\x03m13\x18\x08 \x01(\x02:\x010\x12\x0e\n\x03m20\x18\t \x01(\x02:\x010\x12\x0e\n\x03m21\x18\n \x01(\x02:\x010\x12\x0e\n\x03m22\x18\x0b \x01(\x02:\x011\x12\x0e\n\x03m23\x18\x0c \x01(\x02:\x010\x12\x0e\n\x03m30\x18\r \x01(\x02:\x010\x12\x0e\n\x03m31\x18\x0e \x01(\x02:\x010\x12\x0e\n\x03m32\x18\x0f \x01(\x02:\x010\x12\x0e\n\x03m33\x18\x10 \x01(\x02:\x011:\x14\x82\xb5\x18\x10dmVMath::Matrix4BH\n\x10com.dynamo.protoB\x07DdfMath\x92\xb5\x18)dmsdk/dlib/vmath.h dmsdk/dlib/transform.h')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ddf.ddf_math_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'\n\x10com.dynamo.protoB\x07DdfMath\x92\xb5\x18)dmsdk/dlib/vmath.h dmsdk/dlib/transform.h'
    _POINT3._options = None
    _POINT3._serialized_options = b'\x82\xb5\x18\x0fdmVMath::Point3'
    _VECTOR3._options = None
    _VECTOR3._serialized_options = b'\x82\xb5\x18\x10dmVMath::Vector3'
    _VECTOR3ONE._options = None
    _VECTOR3ONE._serialized_options = b'\x82\xb5\x18\x10dmVMath::Vector3'
    _VECTOR4._options = None
    _VECTOR4._serialized_options = b'\x82\xb5\x18\x10dmVMath::Vector4'
    _VECTOR4ONE._options = None
    _VECTOR4ONE._serialized_options = b'\x82\xb5\x18\x10dmVMath::Vector4'
    _VECTOR4WONE._options = None
    _VECTOR4WONE._serialized_options = b'\x82\xb5\x18\x10dmVMath::Vector4'
    _QUAT._options = None
    _QUAT._serialized_options = b'\x82\xb5\x18\rdmVMath::Quat'
    _TRANSFORM._options = None
    _TRANSFORM._serialized_options = b'\x82\xb5\x18\x16dmTransform::Transform'
    _MATRIX4._options = None
    _MATRIX4._serialized_options = b'\x82\xb5\x18\x10dmVMath::Matrix4'
    _POINT3._serialized_start = 56
    _POINT3._serialized_end = 141
    _VECTOR3._serialized_start = 143
    _VECTOR3._serialized_end = 230
    _VECTOR3ONE._serialized_start = 232
    _VECTOR3ONE._serialized_end = 322
    _VECTOR4._serialized_start = 324
    _VECTOR4._serialized_end = 411
    _VECTOR4ONE._serialized_start = 413
    _VECTOR4ONE._serialized_end = 503
    _VECTOR4WONE._serialized_start = 505
    _VECTOR4WONE._serialized_end = 596
    _QUAT._serialized_start = 598
    _QUAT._serialized_end = 679
    _TRANSFORM._serialized_start = 682
    _TRANSFORM._serialized_end = 823
    _MATRIX4._serialized_start = 826
    _MATRIX4._serialized_end = 1113



"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from defoldsdk.ddf import ddf_extensions_pb2 as ddf_dot_ddf__extensions__pb2
from defoldsdk.ddf import ddf_math_pb2 as ddf_dot_ddf__math__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15render/font_ddf.proto\x12\x0bdmRenderDDF\x1a\x18ddf/ddf_extensions.proto\x1a\x12ddf/ddf_math.proto"\x81\x04\n\x08FontDesc\x12\x12\n\x04font\x18\x01 \x02(\tB\x04\xa0\xbb\x18\x01\x12\x16\n\x08material\x18\x02 \x02(\tB\x04\xa0\xbb\x18\x01\x12\x0c\n\x04size\x18\x03 \x02(\r\x12\x14\n\tantialias\x18\x04 \x01(\r:\x011\x12\x10\n\x05alpha\x18\x05 \x01(\x02:\x011\x12\x18\n\routline_alpha\x18\x06 \x01(\x02:\x010\x12\x18\n\routline_width\x18\x07 \x01(\x02:\x010\x12\x17\n\x0cshadow_alpha\x18\x08 \x01(\x02:\x010\x12\x16\n\x0bshadow_blur\x18\t \x01(\r:\x010\x12\x13\n\x08shadow_x\x18\n \x01(\x02:\x010\x12\x13\n\x08shadow_y\x18\x0b \x01(\x02:\x010\x12\x1a\n\x10extra_characters\x18\x0c \x01(\t:\x00\x12B\n\routput_format\x18\r \x01(\x0e2\x1e.dmRenderDDF.FontTextureFormat:\x0bTYPE_BITMAP\x12\x18\n\tall_chars\x18\x0e \x01(\x08:\x05false\x12\x16\n\x0bcache_width\x18\x0f \x01(\r:\x010\x12\x17\n\x0ccache_height\x18\x10 \x01(\r:\x010\x12C\n\x0brender_mode\x18\x11 \x01(\x0e2\x1b.dmRenderDDF.FontRenderMode:\x11MODE_SINGLE_LAYER\x12\x14\n\ncharacters\x18\x12 \x01(\t:\x00"\xaa\x06\n\tGlyphBank\x12,\n\x06glyphs\x18\x01 \x03(\x0b2\x1c.dmRenderDDF.GlyphBank.Glyph\x12\x18\n\rglyph_padding\x18\x02 \x01(\x04:\x010\x12\x19\n\x0eglyph_channels\x18\x03 \x01(\r:\x010\x12\x12\n\nglyph_data\x18\x04 \x01(\x0c\x12\x15\n\nmax_ascent\x18\x05 \x01(\x02:\x010\x12\x16\n\x0bmax_descent\x18\x06 \x01(\x02:\x010\x12\x16\n\x0bmax_advance\x18\x07 \x01(\x02:\x010\x12\x14\n\tmax_width\x18\x08 \x01(\x02:\x010\x12\x15\n\nmax_height\x18\t \x01(\x02:\x010\x12A\n\x0cimage_format\x18\n \x01(\x0e2\x1e.dmRenderDDF.FontTextureFormat:\x0bTYPE_BITMAP\x12\x15\n\nsdf_spread\x18\x0b \x01(\x02:\x011\x12\x16\n\x0bsdf_outline\x18\x0c \x01(\x02:\x010\x12\x15\n\nsdf_shadow\x18\r \x01(\x02:\x010\x12\x16\n\x0bcache_width\x18\x0e \x01(\r:\x010\x12\x17\n\x0ccache_height\x18\x0f \x01(\r:\x010\x12\x1b\n\x10cache_cell_width\x18\x10 \x01(\r:\x010\x12\x1c\n\x11cache_cell_height\x18\x11 \x01(\r:\x010\x12 \n\x15cache_cell_max_ascent\x18\x12 \x01(\r:\x010\x12\x12\n\x07padding\x18\x13 \x01(\r:\x010\x12\x1c\n\ris_monospaced\x18\x14 \x01(\x08:\x05false\x1a\xe8\x01\n\x05Glyph\x12\x11\n\tcharacter\x18\x01 \x02(\r\x12\x10\n\x05width\x18\x02 \x01(\x02:\x010\x12\x16\n\x0bimage_width\x18\x03 \x01(\r:\x010\x12\x12\n\x07advance\x18\x04 \x01(\x02:\x010\x12\x17\n\x0cleft_bearing\x18\x05 \x01(\x02:\x010\x12\x11\n\x06ascent\x18\x06 \x01(\x05:\x010\x12\x12\n\x07descent\x18\x07 \x01(\x05:\x010\x12\x0c\n\x01x\x18\x08 \x01(\x05:\x010\x12\x0c\n\x01y\x18\t \x01(\x05:\x010\x12\x19\n\x11glyph_data_offset\x18\n \x01(\x04\x12\x17\n\x0fglyph_data_size\x18\x0b \x01(\x04"\xf8\x04\n\x07FontMap\x12\x18\n\x08material\x18\x01 \x01(\t:\x00B\x04\xa0\xbb\x18\x01\x12\x1a\n\nglyph_bank\x18\x02 \x01(\t:\x00B\x04\xa0\xbb\x18\x01\x12\x14\n\x04font\x18\x03 \x01(\t:\x00B\x04\xa0\xbb\x18\x01\x12\x0f\n\x04size\x18\x04 \x01(\r:\x010\x12\x14\n\tantialias\x18\x05 \x01(\r:\x011\x12\x13\n\x08shadow_x\x18\x06 \x01(\x02:\x010\x12\x13\n\x08shadow_y\x18\x07 \x01(\x02:\x010\x12\x16\n\x0bshadow_blur\x18\x08 \x01(\r:\x010\x12\x17\n\x0cshadow_alpha\x18\t \x01(\x02:\x011\x12\x10\n\x05alpha\x18\n \x01(\x02:\x011\x12\x18\n\routline_alpha\x18\x0b \x01(\x02:\x011\x12\x18\n\routline_width\x18\x0c \x01(\x02:\x010\x12\x15\n\nlayer_mask\x18\r \x01(\r:\x011\x12B\n\routput_format\x18\x0e \x01(\x0e2\x1e.dmRenderDDF.FontTextureFormat:\x0bTYPE_BITMAP\x12C\n\x0brender_mode\x18\x0f \x01(\x0e2\x1b.dmRenderDDF.FontRenderMode:\x11MODE_SINGLE_LAYER\x12\x18\n\tall_chars\x18\x10 \x01(\x08:\x05false\x12\x14\n\ncharacters\x18\x11 \x01(\t:\x00\x12\x16\n\x0bcache_width\x18\x12 \x01(\r:\x010\x12\x17\n\x0ccache_height\x18\x13 \x01(\r:\x010\x12\x15\n\nsdf_spread\x18\x14 \x01(\x02:\x011\x12\x16\n\x0bsdf_outline\x18\x15 \x01(\x02:\x010\x12\x15\n\nsdf_shadow\x18\x16 \x01(\x02:\x010\x12\x12\n\x07padding\x18\x17 \x01(\r:\x010*]\n\x11FontTextureFormat\x12\x1b\n\x0bTYPE_BITMAP\x10\x00\x1a\n\xc2\xc1\x18\x06Bitmap\x12+\n\x13TYPE_DISTANCE_FIELD\x10\x01\x1a\x12\xc2\xc1\x18\x0eDistance Field*`\n\x0eFontRenderMode\x12\'\n\x11MODE_SINGLE_LAYER\x10\x00\x1a\x10\xc2\xc1\x18\x0cSingle Layer\x12%\n\x10MODE_MULTI_LAYER\x10\x01\x1a\x0f\xc2\xc1\x18\x0bMulti LayerB\x1f\n\x17com.dynamo.render.protoB\x04Font')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'render.font_ddf_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'\n\x17com.dynamo.render.protoB\x04Font'
    _FONTTEXTUREFORMAT.values_by_name['TYPE_BITMAP']._options = None
    _FONTTEXTUREFORMAT.values_by_name['TYPE_BITMAP']._serialized_options = b'\xc2\xc1\x18\x06Bitmap'
    _FONTTEXTUREFORMAT.values_by_name['TYPE_DISTANCE_FIELD']._options = None
    _FONTTEXTUREFORMAT.values_by_name['TYPE_DISTANCE_FIELD']._serialized_options = b'\xc2\xc1\x18\x0eDistance Field'
    _FONTRENDERMODE.values_by_name['MODE_SINGLE_LAYER']._options = None
    _FONTRENDERMODE.values_by_name['MODE_SINGLE_LAYER']._serialized_options = b'\xc2\xc1\x18\x0cSingle Layer'
    _FONTRENDERMODE.values_by_name['MODE_MULTI_LAYER']._options = None
    _FONTRENDERMODE.values_by_name['MODE_MULTI_LAYER']._serialized_options = b'\xc2\xc1\x18\x0bMulti Layer'
    _FONTDESC.fields_by_name['font']._options = None
    _FONTDESC.fields_by_name['font']._serialized_options = b'\xa0\xbb\x18\x01'
    _FONTDESC.fields_by_name['material']._options = None
    _FONTDESC.fields_by_name['material']._serialized_options = b'\xa0\xbb\x18\x01'
    _FONTMAP.fields_by_name['material']._options = None
    _FONTMAP.fields_by_name['material']._serialized_options = b'\xa0\xbb\x18\x01'
    _FONTMAP.fields_by_name['glyph_bank']._options = None
    _FONTMAP.fields_by_name['glyph_bank']._serialized_options = b'\xa0\xbb\x18\x01'
    _FONTMAP.fields_by_name['font']._options = None
    _FONTMAP.fields_by_name['font']._serialized_options = b'\xa0\xbb\x18\x01'
    _FONTTEXTUREFORMAT._serialized_start = 2048
    _FONTTEXTUREFORMAT._serialized_end = 2141
    _FONTRENDERMODE._serialized_start = 2143
    _FONTRENDERMODE._serialized_end = 2239
    _FONTDESC._serialized_start = 85
    _FONTDESC._serialized_end = 598
    _GLYPHBANK._serialized_start = 601
    _GLYPHBANK._serialized_end = 1411
    _GLYPHBANK_GLYPH._serialized_start = 1179
    _GLYPHBANK_GLYPH._serialized_end = 1411
    _FONTMAP._serialized_start = 1414
    _FONTMAP._serialized_end = 2046



"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from defoldsdk.ddf import ddf_extensions_pb2 as ddf_dot_ddf__extensions__pb2
from defoldsdk.ddf import ddf_math_pb2 as ddf_dot_ddf__math__pb2
from defoldsdk.gamesys import tile_ddf_pb2 as gamesys_dot_tile__ddf__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dgamesys/texture_set_ddf.proto\x12\x0fdmGameSystemDDF\x1a\x18ddf/ddf_extensions.proto\x1a\x12ddf/ddf_math.proto\x1a\x16gamesys/tile_ddf.proto"\xe7\x01\n\x13TextureSetAnimation\x12\n\n\x02id\x18\x01 \x02(\t\x12\r\n\x05width\x18\x02 \x02(\r\x12\x0e\n\x06height\x18\x03 \x02(\r\x12\r\n\x05start\x18\x04 \x02(\r\x12\x0b\n\x03end\x18\x05 \x02(\r\x12\x0f\n\x03fps\x18\x06 \x01(\r:\x0230\x12B\n\x08playback\x18\x07 \x01(\x0e2\x19.dmGameSystemDDF.Playback:\x15PLAYBACK_ONCE_FORWARD\x12\x1a\n\x0fflip_horizontal\x18\x08 \x01(\r:\x010\x12\x18\n\rflip_vertical\x18\t \x01(\r:\x010"\x8a\x02\n\x0eSpriteGeometry\x12\r\n\x05width\x18\x01 \x02(\r\x12\x0e\n\x06height\x18\x02 \x02(\r\x12\x10\n\x08center_x\x18\x03 \x02(\x02\x12\x10\n\x08center_y\x18\x04 \x02(\x02\x12\x0f\n\x07rotated\x18\x05 \x02(\x08\x12L\n\ttrim_mode\x18\x06 \x02(\x0e2#.dmGameSystemDDF.SpriteTrimmingMode:\x14SPRITE_TRIM_MODE_OFF\x12\x10\n\x08vertices\x18\x07 \x03(\x02\x12\x0b\n\x03uvs\x18\x08 \x03(\x02\x12\x0f\n\x07indices\x18\t \x03(\r\x12\x12\n\x07pivot_x\x18\n \x01(\x02:\x010\x12\x12\n\x07pivot_y\x18\x0b \x01(\x02:\x010"\x8d\x04\n\nTextureSet\x12\x15\n\x07texture\x18\x01 \x02(\tB\x04\xa0\xbb\x18\x01\x12\r\n\x05width\x18\x02 \x02(\r\x12\x0e\n\x06height\x18\x03 \x02(\r\x12\x14\n\x0ctexture_hash\x18\x04 \x01(\x04\x128\n\nanimations\x18\x05 \x03(\x0b2$.dmGameSystemDDF.TextureSetAnimation\x12\x12\n\ntile_width\x18\x06 \x01(\r\x12\x13\n\x0btile_height\x18\x07 \x01(\r\x12\x12\n\ntile_count\x18\x08 \x01(\r\x12\x1d\n\x15collision_hull_points\x18\t \x03(\x02\x12\x18\n\x10collision_groups\x18\n \x03(\t\x121\n\x0cconvex_hulls\x18\x0b \x03(\x0b2\x1b.dmGameSystemDDF.ConvexHull\x12\x19\n\x11image_name_hashes\x18\x0c \x03(\x04\x12\x15\n\rframe_indices\x18\r \x03(\r\x12\x12\n\ntex_coords\x18\x0e \x02(\x0c\x12\x10\n\x08tex_dims\x18\x0f \x01(\x0c\x123\n\ngeometries\x18\x10 \x03(\x0b2\x1f.dmGameSystemDDF.SpriteGeometry\x12\x16\n\x0euse_geometries\x18\x11 \x01(\r\x12\x14\n\x0cpage_indices\x18\x12 \x03(\r\x12\x15\n\npage_count\x18\x13 \x01(\r:\x010B+\n\x18com.dynamo.gamesys.protoB\x0fTextureSetProto')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gamesys.texture_set_ddf_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'\n\x18com.dynamo.gamesys.protoB\x0fTextureSetProto'
    _TEXTURESET.fields_by_name['texture']._options = None
    _TEXTURESET.fields_by_name['texture']._serialized_options = b'\xa0\xbb\x18\x01'
    _TEXTURESETANIMATION._serialized_start = 121
    _TEXTURESETANIMATION._serialized_end = 352
    _SPRITEGEOMETRY._serialized_start = 355
    _SPRITEGEOMETRY._serialized_end = 621
    _TEXTURESET._serialized_start = 624
    _TEXTURESET._serialized_end = 1149



"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from defoldsdk.ddf import ddf_extensions_pb2 as ddf_dot_ddf__extensions__pb2
from defoldsdk.ddf import ddf_math_pb2 as ddf_dot_ddf__math__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dresource/liveupdate_ddf.proto\x12\x0fdmLiveUpdateDDF\x1a\x18ddf/ddf_extensions.proto\x1a\x12ddf/ddf_math.proto"\x1a\n\nHashDigest\x12\x0c\n\x04data\x18\x01 \x02(\x0c"\xb2\x02\n\x0eManifestHeader\x12L\n\x17resource_hash_algorithm\x18\x01 \x02(\x0e2\x1e.dmLiveUpdateDDF.HashAlgorithm:\x0bHASH_SHA256\x12M\n\x18signature_hash_algorithm\x18\x02 \x02(\x0e2\x1e.dmLiveUpdateDDF.HashAlgorithm:\x0bHASH_SHA256\x12J\n\x18signature_sign_algorithm\x18\x03 \x02(\x0e2\x1e.dmLiveUpdateDDF.SignAlgorithm:\x08SIGN_RSA\x127\n\x12project_identifier\x18\x04 \x02(\x0b2\x1b.dmLiveUpdateDDF.HashDigest"\xa6\x01\n\rResourceEntry\x12)\n\x04hash\x18\x01 \x02(\x0b2\x1b.dmLiveUpdateDDF.HashDigest\x12\x0b\n\x03url\x18\x02 \x02(\t\x12\x10\n\x08url_hash\x18\x03 \x02(\x04\x12\x0c\n\x04size\x18\x04 \x02(\r\x12\x17\n\x0fcompressed_size\x18\x05 \x02(\r\x12\x10\n\x05flags\x18\x06 \x02(\r:\x010\x12\x12\n\ndependants\x18\x07 \x03(\x04"\xa8\x01\n\x0cManifestData\x12/\n\x06header\x18\x01 \x02(\x0b2\x1f.dmLiveUpdateDDF.ManifestHeader\x124\n\x0fengine_versions\x18\x02 \x03(\x0b2\x1b.dmLiveUpdateDDF.HashDigest\x121\n\tresources\x18\x03 \x03(\x0b2\x1e.dmLiveUpdateDDF.ResourceEntry"_\n\x0cManifestFile\x12\x0c\n\x04data\x18\x01 \x02(\x0c\x12\x11\n\tsignature\x18\x02 \x02(\x0c\x12\x1a\n\x12archive_identifier\x18\x03 \x01(\x0c\x12\x12\n\x07version\x18\x04 \x02(\r:\x010*`\n\rHashAlgorithm\x12\x10\n\x0cHASH_UNKNOWN\x10\x00\x12\x0c\n\x08HASH_MD5\x10\x01\x12\r\n\tHASH_SHA1\x10\x02\x12\x0f\n\x0bHASH_SHA256\x10\x03\x12\x0f\n\x0bHASH_SHA512\x10\x04*/\n\rSignAlgorithm\x12\x10\n\x0cSIGN_UNKNOWN\x10\x00\x12\x0c\n\x08SIGN_RSA\x10\x01*M\n\x11ResourceEntryFlag\x12\x0b\n\x07BUNDLED\x10\x01\x12\x0c\n\x08EXCLUDED\x10\x02\x12\r\n\tENCRYPTED\x10\x04\x12\x0e\n\nCOMPRESSED\x10\x08B\'\n\x1bcom.dynamo.liveupdate.protoB\x08Manifest')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'resource.liveupdate_ddf_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'\n\x1bcom.dynamo.liveupdate.protoB\x08Manifest'
    _HASHALGORITHM._serialized_start = 870
    _HASHALGORITHM._serialized_end = 966
    _SIGNALGORITHM._serialized_start = 968
    _SIGNALGORITHM._serialized_end = 1015
    _RESOURCEENTRYFLAG._serialized_start = 1017
    _RESOURCEENTRYFLAG._serialized_end = 1094
    _HASHDIGEST._serialized_start = 96
    _HASHDIGEST._serialized_end = 122
    _MANIFESTHEADER._serialized_start = 125
    _MANIFESTHEADER._serialized_end = 431
    _RESOURCEENTRY._serialized_start = 434
    _RESOURCEENTRY._serialized_end = 600
    _MANIFESTDATA._serialized_start = 603
    _MANIFESTDATA._serialized_end = 771
    _MANIFESTFILE._serialized_start = 773
    _MANIFESTFILE._serialized_end = 868



"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from defoldsdk.ddf import ddf_extensions_pb2 as ddf_dot_ddf__extensions__pb2
from defoldsdk.ddf import ddf_math_pb2 as ddf_dot_ddf__math__pb2
from defoldsdk.gameobject import properties_ddf_pb2 as gameobject_dot_properties__ddf__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fgameobject/gameobject_ddf.proto\x12\x0fdmGameObjectDDF\x1a\x18ddf/ddf_extensions.proto\x1a\x12ddf/ddf_math.proto\x1a\x1fgameobject/properties_ddf.proto"V\n\x0cPropertyDesc\x12\n\n\x02id\x18\x01 \x02(\t\x12\r\n\x05value\x18\x02 \x02(\t\x12+\n\x04type\x18\x03 \x02(\x0e2\x1d.dmGameObjectDDF.PropertyType"\x91\x02\n\rComponentDesc\x12\n\n\x02id\x18\x01 \x02(\t\x12\x17\n\tcomponent\x18\x02 \x02(\tB\x04\xa0\xbb\x18\x01\x12 \n\x08position\x18\x03 \x01(\x0b2\x0e.dmMath.Point3\x12\x1e\n\x08rotation\x18\x04 \x01(\x0b2\x0c.dmMath.Quat\x121\n\nproperties\x18\x05 \x03(\x0b2\x1d.dmGameObjectDDF.PropertyDesc\x12C\n\x0eproperty_decls\x18\x06 \x01(\x0b2%.dmPropertiesDDF.PropertyDeclarationsB\x04\xa8\xbb\x18\x01\x12!\n\x05scale\x18\x07 \x01(\x0b2\x12.dmMath.Vector3One"\xa4\x01\n\x15EmbeddedComponentDesc\x12\n\n\x02id\x18\x01 \x02(\t\x12\x0c\n\x04type\x18\x02 \x02(\t\x12\x0c\n\x04data\x18\x03 \x02(\t\x12 \n\x08position\x18\x04 \x01(\x0b2\x0e.dmMath.Point3\x12\x1e\n\x08rotation\x18\x05 \x01(\x0b2\x0c.dmMath.Quat\x12!\n\x05scale\x18\x06 \x01(\x0b2\x12.dmMath.Vector3One"\xae\x01\n\rPrototypeDesc\x122\n\ncomponents\x18\x01 \x03(\x0b2\x1e.dmGameObjectDDF.ComponentDesc\x12C\n\x13embedded_components\x18\x02 \x03(\x0b2&.dmGameObjectDDF.EmbeddedComponentDesc\x12$\n\x12property_resources\x18\x03 \x03(\tB\x08\xa8\xbb\x18\x01\xa0\xbb\x18\x01"\x9b\x01\n\x15ComponentPropertyDesc\x12\n\n\x02id\x18\x01 \x02(\t\x121\n\nproperties\x18\x02 \x03(\x0b2\x1d.dmGameObjectDDF.PropertyDesc\x12C\n\x0eproperty_decls\x18\x03 \x01(\x0b2%.dmPropertiesDDF.PropertyDeclarationsB\x04\xa8\xbb\x18\x01"8\n\x10ComponenTypeDesc\x12\x11\n\tname_hash\x18\x01 \x02(\x04\x12\x11\n\tmax_count\x18\x02 \x02(\r"\x83\x02\n\x0cInstanceDesc\x12\n\n\x02id\x18\x01 \x02(\t\x12\x17\n\tprototype\x18\x02 \x02(\tB\x04\xa0\xbb\x18\x01\x12\x10\n\x08children\x18\x03 \x03(\t\x12 \n\x08position\x18\x04 \x01(\x0b2\x0e.dmMath.Point3\x12\x1e\n\x08rotation\x18\x05 \x01(\x0b2\x0c.dmMath.Quat\x12D\n\x14component_properties\x18\x06 \x03(\x0b2&.dmGameObjectDDF.ComponentPropertyDesc\x12\x10\n\x05scale\x18\x07 \x01(\x02:\x011\x12"\n\x06scale3\x18\x08 \x01(\x0b2\x12.dmMath.Vector3One"\x80\x02\n\x14EmbeddedInstanceDesc\x12\n\n\x02id\x18\x01 \x02(\t\x12\x10\n\x08children\x18\x02 \x03(\t\x12\x0c\n\x04data\x18\x03 \x02(\t\x12 \n\x08position\x18\x04 \x01(\x0b2\x0e.dmMath.Point3\x12\x1e\n\x08rotation\x18\x05 \x01(\x0b2\x0c.dmMath.Quat\x12D\n\x14component_properties\x18\x06 \x03(\x0b2&.dmGameObjectDDF.ComponentPropertyDesc\x12\x10\n\x05scale\x18\x07 \x01(\x02:\x011\x12"\n\x06scale3\x18\x08 \x01(\x0b2\x12.dmMath.Vector3One"^\n\x14InstancePropertyDesc\x12\n\n\x02id\x18\x01 \x02(\t\x12:\n\nproperties\x18\x02 \x03(\x0b2&.dmGameObjectDDF.ComponentPropertyDesc"\xfa\x01\n\x16CollectionInstanceDesc\x12\n\n\x02id\x18\x01 \x02(\t\x12\x18\n\ncollection\x18\x02 \x02(\tB\x04\xa0\xbb\x18\x01\x12 \n\x08position\x18\x03 \x01(\x0b2\x0e.dmMath.Point3\x12\x1e\n\x08rotation\x18\x04 \x01(\x0b2\x0c.dmMath.Quat\x12\x10\n\x05scale\x18\x05 \x01(\x02:\x011\x12"\n\x06scale3\x18\x07 \x01(\x0b2\x12.dmMath.Vector3One\x12B\n\x13instance_properties\x18\x06 \x03(\x0b2%.dmGameObjectDDF.InstancePropertyDesc"\xdc\x02\n\x0eCollectionDesc\x12\x0c\n\x04name\x18\x01 \x02(\t\x120\n\tinstances\x18\x02 \x03(\x0b2\x1d.dmGameObjectDDF.InstanceDesc\x12E\n\x14collection_instances\x18\x03 \x03(\x0b2\'.dmGameObjectDDF.CollectionInstanceDesc\x12\x18\n\rscale_along_z\x18\x04 \x01(\r:\x010\x12A\n\x12embedded_instances\x18\x05 \x03(\x0b2%.dmGameObjectDDF.EmbeddedInstanceDesc\x12$\n\x12property_resources\x18\x06 \x03(\tB\x08\xa8\xbb\x18\x01\xa0\xbb\x18\x01\x12@\n\x0fcomponent_types\x18\x07 \x03(\x0b2!.dmGameObjectDDF.ComponenTypeDescB\x04\xa8\xbb\x18\x01"\x13\n\x11AcquireInputFocus"\x13\n\x11ReleaseInputFocus"B\n\tSetParent\x12\x14\n\tparent_id\x18\x01 \x01(\x04:\x010\x12\x1f\n\x14keep_world_transform\x18\x02 \x01(\r:\x011"\x08\n\x06Enable"\t\n\x07Disable"h\n\rScriptMessage\x12\x17\n\x0fdescriptor_hash\x18\x01 \x02(\x04\x12\x14\n\x0cpayload_size\x18\x02 \x02(\r\x12\x10\n\x08function\x18\x03 \x01(\r\x12\x16\n\x0eunref_function\x18\x04 \x01(\x08"\'\n\x12ScriptUnrefMessage\x12\x11\n\treference\x18\x01 \x02(\r*\xf4\x01\n\x0cPropertyType\x12\x18\n\x14PROPERTY_TYPE_NUMBER\x10\x00\x12\x16\n\x12PROPERTY_TYPE_HASH\x10\x01\x12\x15\n\x11PROPERTY_TYPE_URL\x10\x02\x12\x19\n\x15PROPERTY_TYPE_VECTOR3\x10\x03\x12\x19\n\x15PROPERTY_TYPE_VECTOR4\x10\x04\x12\x16\n\x12PROPERTY_TYPE_QUAT\x10\x05\x12\x19\n\x15PROPERTY_TYPE_BOOLEAN\x10\x06\x12\x19\n\x15PROPERTY_TYPE_MATRIX4\x10\x07\x12\x17\n\x13PROPERTY_TYPE_COUNT\x10\x08B)\n\x1bcom.dynamo.gameobject.protoB\nGameObject')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gameobject.gameobject_ddf_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'\n\x1bcom.dynamo.gameobject.protoB\nGameObject'
    _COMPONENTDESC.fields_by_name['component']._options = None
    _COMPONENTDESC.fields_by_name['component']._serialized_options = b'\xa0\xbb\x18\x01'
    _COMPONENTDESC.fields_by_name['property_decls']._options = None
    _COMPONENTDESC.fields_by_name['property_decls']._serialized_options = b'\xa8\xbb\x18\x01'
    _PROTOTYPEDESC.fields_by_name['property_resources']._options = None
    _PROTOTYPEDESC.fields_by_name['property_resources']._serialized_options = b'\xa8\xbb\x18\x01\xa0\xbb\x18\x01'
    _COMPONENTPROPERTYDESC.fields_by_name['property_decls']._options = None
    _COMPONENTPROPERTYDESC.fields_by_name['property_decls']._serialized_options = b'\xa8\xbb\x18\x01'
    _INSTANCEDESC.fields_by_name['prototype']._options = None
    _INSTANCEDESC.fields_by_name['prototype']._serialized_options = b'\xa0\xbb\x18\x01'
    _COLLECTIONINSTANCEDESC.fields_by_name['collection']._options = None
    _COLLECTIONINSTANCEDESC.fields_by_name['collection']._serialized_options = b'\xa0\xbb\x18\x01'
    _COLLECTIONDESC.fields_by_name['property_resources']._options = None
    _COLLECTIONDESC.fields_by_name['property_resources']._serialized_options = b'\xa8\xbb\x18\x01\xa0\xbb\x18\x01'
    _COLLECTIONDESC.fields_by_name['component_types']._options = None
    _COLLECTIONDESC.fields_by_name['component_types']._serialized_options = b'\xa8\xbb\x18\x01'
    _PROPERTYTYPE._serialized_start = 2555
    _PROPERTYTYPE._serialized_end = 2799
    _PROPERTYDESC._serialized_start = 131
    _PROPERTYDESC._serialized_end = 217
    _COMPONENTDESC._serialized_start = 220
    _COMPONENTDESC._serialized_end = 493
    _EMBEDDEDCOMPONENTDESC._serialized_start = 496
    _EMBEDDEDCOMPONENTDESC._serialized_end = 660
    _PROTOTYPEDESC._serialized_start = 663
    _PROTOTYPEDESC._serialized_end = 837
    _COMPONENTPROPERTYDESC._serialized_start = 840
    _COMPONENTPROPERTYDESC._serialized_end = 995
    _COMPONENTYPEDESC._serialized_start = 997
    _COMPONENTYPEDESC._serialized_end = 1053
    _INSTANCEDESC._serialized_start = 1056
    _INSTANCEDESC._serialized_end = 1315
    _EMBEDDEDINSTANCEDESC._serialized_start = 1318
    _EMBEDDEDINSTANCEDESC._serialized_end = 1574
    _INSTANCEPROPERTYDESC._serialized_start = 1576
    _INSTANCEPROPERTYDESC._serialized_end = 1670
    _COLLECTIONINSTANCEDESC._serialized_start = 1673
    _COLLECTIONINSTANCEDESC._serialized_end = 1923
    _COLLECTIONDESC._serialized_start = 1926
    _COLLECTIONDESC._serialized_end = 2274
    _ACQUIREINPUTFOCUS._serialized_start = 2276
    _ACQUIREINPUTFOCUS._serialized_end = 2295
    _RELEASEINPUTFOCUS._serialized_start = 2297
    _RELEASEINPUTFOCUS._serialized_end = 2316
    _SETPARENT._serialized_start = 2318
    _SETPARENT._serialized_end = 2384
    _ENABLE._serialized_start = 2386
    _ENABLE._serialized_end = 2394
    _DISABLE._serialized_start = 2396
    _DISABLE._serialized_end = 2405
    _SCRIPTMESSAGE._serialized_start = 2407
    _SCRIPTMESSAGE._serialized_end = 2511
    _SCRIPTUNREFMESSAGE._serialized_start = 2513
    _SCRIPTUNREFMESSAGE._serialized_end = 2552



from .render import *
from .script import *
from .engine import *
from .gamesys import *
from .graphics import *
from .ddf import *
from .gameobject import *
from .resource import *

import importlib , pkgutil , collections , os 
from google.protobuf.descriptor import FieldDescriptor
from google.protobuf.text_format import  Parse , MessageToString
from google.protobuf.json_format import MessageToDict , MessageToJson , ParseDict

class TypesGenerator : 
    def getDefoldTypes(self) : 
        result = dict()
        pkg_lib = importlib.import_module('defoldsdk')
        for elem in dir(pkg_lib) : 
            may_msg = pkg_lib.__getattribute__(elem)
            if type(may_msg).__name__ == 'MessageMeta' : 
                result[may_msg.__name__] = may_msg
        return collections.namedtuple('defoldsdk' , result.keys() )(**result)
sdk = TypesGenerator().getDefoldTypes()
__all__ = ["sdk"]




"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from defoldsdk.ddf import ddf_extensions_pb2 as ddf_dot_ddf__extensions__pb2
from defoldsdk.ddf import ddf_math_pb2 as ddf_dot_ddf__math__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16gamesys/mesh_ddf.proto\x12\tdmMeshDDF\x1a\x18ddf/ddf_extensions.proto\x1a\x12ddf/ddf_math.proto"\xde\x02\n\x08MeshDesc\x12\x16\n\x08material\x18\x01 \x02(\tB\x04\xa0\xbb\x18\x01\x12\x16\n\x08vertices\x18\x02 \x02(\tB\x04\xa0\xbb\x18\x01\x12\x16\n\x08textures\x18\x03 \x03(\tB\x04\xa0\xbb\x18\x01\x12N\n\x0eprimitive_type\x18\x04 \x01(\x0e2!.dmMeshDDF.MeshDesc.PrimitiveType:\x13PRIMITIVE_TRIANGLES\x12\x17\n\x0fposition_stream\x18\x05 \x01(\t\x12\x15\n\rnormal_stream\x18\x06 \x01(\t"\x89\x01\n\rPrimitiveType\x12\x1e\n\x0fPRIMITIVE_LINES\x10\x01\x1a\t\xc2\xc1\x18\x05Lines\x12&\n\x13PRIMITIVE_TRIANGLES\x10\x04\x1a\r\xc2\xc1\x18\tTriangles\x120\n\x18PRIMITIVE_TRIANGLE_STRIP\x10\x05\x1a\x12\xc2\xc1\x18\x0eTriangle StripB%\n\x18com.dynamo.gamesys.protoB\tMeshProto')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gamesys.mesh_ddf_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'\n\x18com.dynamo.gamesys.protoB\tMeshProto'
    _MESHDESC_PRIMITIVETYPE.values_by_name['PRIMITIVE_LINES']._options = None
    _MESHDESC_PRIMITIVETYPE.values_by_name['PRIMITIVE_LINES']._serialized_options = b'\xc2\xc1\x18\x05Lines'
    _MESHDESC_PRIMITIVETYPE.values_by_name['PRIMITIVE_TRIANGLES']._options = None
    _MESHDESC_PRIMITIVETYPE.values_by_name['PRIMITIVE_TRIANGLES']._serialized_options = b'\xc2\xc1\x18\tTriangles'
    _MESHDESC_PRIMITIVETYPE.values_by_name['PRIMITIVE_TRIANGLE_STRIP']._options = None
    _MESHDESC_PRIMITIVETYPE.values_by_name['PRIMITIVE_TRIANGLE_STRIP']._serialized_options = b'\xc2\xc1\x18\x0eTriangle Strip'
    _MESHDESC.fields_by_name['material']._options = None
    _MESHDESC.fields_by_name['material']._serialized_options = b'\xa0\xbb\x18\x01'
    _MESHDESC.fields_by_name['vertices']._options = None
    _MESHDESC.fields_by_name['vertices']._serialized_options = b'\xa0\xbb\x18\x01'
    _MESHDESC.fields_by_name['textures']._options = None
    _MESHDESC.fields_by_name['textures']._serialized_options = b'\xa0\xbb\x18\x01'
    _MESHDESC._serialized_start = 84
    _MESHDESC._serialized_end = 434
    _MESHDESC_PRIMITIVETYPE._serialized_start = 297
    _MESHDESC_PRIMITIVETYPE._serialized_end = 434



"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from defoldsdk.ddf import ddf_extensions_pb2 as ddf_dot_ddf__extensions__pb2
from defoldsdk.ddf import ddf_math_pb2 as ddf_dot_ddf__math__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19gamesys/gamesys_ddf.proto\x12\x0fdmGameSystemDDF\x1a\x18ddf/ddf_extensions.proto\x1a\x12ddf/ddf_math.proto"i\n\x0bFactoryDesc\x12\x17\n\tprototype\x18\x01 \x02(\tB\x04\xa0\xbb\x18\x01\x12\x1f\n\x10load_dynamically\x18\x02 \x01(\x08:\x05false\x12 \n\x11dynamic_prototype\x18\x03 \x01(\x08:\x05false"s\n\x15CollectionFactoryDesc\x12\x17\n\tprototype\x18\x01 \x02(\tB\x04\xa0\xbb\x18\x01\x12\x1f\n\x10load_dynamically\x18\x02 \x01(\x08:\x05false\x12 \n\x11dynamic_prototype\x18\x03 \x01(\x08:\x05false"\x9e\x01\n\x06Create\x12&\n\x08position\x18\x01 \x02(\x0b2\x0e.dmMath.Point3B\x04\xa0\xb5\x18\x01\x12$\n\x08rotation\x18\x02 \x02(\x0b2\x0c.dmMath.QuatB\x04\xa0\xb5\x18\x01\x12\r\n\x02id\x18\x03 \x01(\x04:\x010\x12\x10\n\x05scale\x18\x04 \x01(\x02:\x011\x12%\n\x06scale3\x18\x05 \x01(\x0b2\x0f.dmMath.Vector3B\x04\xa0\xb5\x18\x01"G\n\x13CollectionProxyDesc\x12\x18\n\ncollection\x18\x01 \x02(\tB\x04\xa0\xbb\x18\x01\x12\x16\n\x07exclude\x18\x02 \x01(\x08:\x05false"J\n\x0bSetTimeStep\x12\x0e\n\x06factor\x18\x01 \x02(\x02\x12+\n\x04mode\x18\x02 \x02(\x0e2\x1d.dmGameSystemDDF.TimeStepMode"\xd0\x01\n\tLightDesc\x12\n\n\x02id\x18\x01 \x02(\t\x12(\n\x04type\x18\x02 \x02(\x0e2\x1a.dmGameSystemDDF.LightType\x12\x11\n\tintensity\x18\x03 \x02(\x02\x12\x1e\n\x05color\x18\x04 \x02(\x0b2\x0f.dmMath.Vector3\x12\r\n\x05range\x18\x05 \x02(\x02\x12\r\n\x05decay\x18\x06 \x02(\x02\x12\x12\n\ncone_angle\x18\x07 \x01(\x02\x12\x16\n\x0epenumbra_angle\x18\x08 \x01(\x02\x12\x10\n\x08drop_off\x18\t \x01(\x02"w\n\x08SetLight\x12 \n\x08position\x18\x01 \x02(\x0b2\x0e.dmMath.Point3\x12\x1e\n\x08rotation\x18\x02 \x02(\x0b2\x0c.dmMath.Quat\x12)\n\x05light\x18\x03 \x02(\x0b2\x1a.dmGameSystemDDF.LightDesc"c\n\x11SetViewProjection\x12\n\n\x02id\x18\x01 \x02(\x04\x12\x1d\n\x04view\x18\x02 \x02(\x0b2\x0f.dmMath.Matrix4\x12#\n\nprojection\x18\x03 \x02(\x0b2\x0f.dmMath.Matrix4"\x9c\x01\n\tPlaySound\x12\x10\n\x05delay\x18\x01 \x01(\x02:\x010\x12\x0f\n\x04gain\x18\x02 \x01(\x02:\x011\x12\x0e\n\x03pan\x18\x03 \x01(\x02:\x010\x12\x10\n\x05speed\x18\x04 \x01(\x02:\x011\x12\x1b\n\x07play_id\x18\x05 \x01(\r:\n4294967295\x12\x15\n\nstart_time\x18\x06 \x01(\x02:\x010\x12\x16\n\x0bstart_frame\x18\x07 \x01(\r:\x010"(\n\tStopSound\x12\x1b\n\x07play_id\x18\x01 \x01(\r:\n4294967295"!\n\nPauseSound\x12\x13\n\x05pause\x18\x01 \x01(\x08:\x04true" \n\nSoundEvent\x12\x12\n\x07play_id\x18\x01 \x01(\x05:\x010"\x1a\n\x07SetGain\x12\x0f\n\x04gain\x18\x01 \x01(\x02:\x011"\x18\n\x06SetPan\x12\x0e\n\x03pan\x18\x01 \x01(\x02:\x010"\x1c\n\x08SetSpeed\x12\x10\n\x05speed\x18\x01 \x01(\x02:\x011"\x10\n\x0ePlayParticleFX"0\n\x0eStopParticleFX\x12\x1e\n\x0fclear_particles\x18\x01 \x01(\x08:\x05false"x\n\x15SetConstantParticleFX\x12\x12\n\nemitter_id\x18\x01 \x02(\x04\x12\x11\n\tname_hash\x18\x02 \x02(\x04\x12$\n\x05value\x18\x03 \x02(\x0b2\x0f.dmMath.Matrix4B\x04\xa0\xb5\x18\x01\x12\x12\n\nis_matrix4\x18\x04 \x01(\x08"@\n\x17ResetConstantParticleFX\x12\x12\n\nemitter_id\x18\x01 \x02(\x04\x12\x11\n\tname_hash\x18\x02 \x02(\x04"X\n\x0bSetConstant\x12\x11\n\tname_hash\x18\x01 \x02(\x04\x12$\n\x05value\x18\x02 \x02(\x0b2\x0f.dmMath.Vector4B\x04\xa0\xb5\x18\x01\x12\x10\n\x05index\x18\x03 \x01(\x05:\x010""\n\rResetConstant\x12\x11\n\tname_hash\x18\x01 \x02(\x04"0\n\x08SetScale\x12$\n\x05scale\x18\x01 \x02(\x0b2\x0f.dmMath.Vector3B\x04\xa0\xb5\x18\x01*J\n\x0cTimeStepMode\x12\x1d\n\x19TIME_STEP_MODE_CONTINUOUS\x10\x00\x12\x1b\n\x17TIME_STEP_MODE_DISCRETE\x10\x01* \n\tLightType\x12\t\n\x05POINT\x10\x00\x12\x08\n\x04SPOT\x10\x01B&\n\x18com.dynamo.gamesys.protoB\nGameSystem')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gamesys.gamesys_ddf_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'\n\x18com.dynamo.gamesys.protoB\nGameSystem'
    _FACTORYDESC.fields_by_name['prototype']._options = None
    _FACTORYDESC.fields_by_name['prototype']._serialized_options = b'\xa0\xbb\x18\x01'
    _COLLECTIONFACTORYDESC.fields_by_name['prototype']._options = None
    _COLLECTIONFACTORYDESC.fields_by_name['prototype']._serialized_options = b'\xa0\xbb\x18\x01'
    _CREATE.fields_by_name['position']._options = None
    _CREATE.fields_by_name['position']._serialized_options = b'\xa0\xb5\x18\x01'
    _CREATE.fields_by_name['rotation']._options = None
    _CREATE.fields_by_name['rotation']._serialized_options = b'\xa0\xb5\x18\x01'
    _CREATE.fields_by_name['scale3']._options = None
    _CREATE.fields_by_name['scale3']._serialized_options = b'\xa0\xb5\x18\x01'
    _COLLECTIONPROXYDESC.fields_by_name['collection']._options = None
    _COLLECTIONPROXYDESC.fields_by_name['collection']._serialized_options = b'\xa0\xbb\x18\x01'
    _SETCONSTANTPARTICLEFX.fields_by_name['value']._options = None
    _SETCONSTANTPARTICLEFX.fields_by_name['value']._serialized_options = b'\xa0\xb5\x18\x01'
    _SETCONSTANT.fields_by_name['value']._options = None
    _SETCONSTANT.fields_by_name['value']._serialized_options = b'\xa0\xb5\x18\x01'
    _SETSCALE.fields_by_name['scale']._options = None
    _SETSCALE.fields_by_name['scale']._serialized_options = b'\xa0\xb5\x18\x01'
    _TIMESTEPMODE._serialized_start = 1845
    _TIMESTEPMODE._serialized_end = 1919
    _LIGHTTYPE._serialized_start = 1921
    _LIGHTTYPE._serialized_end = 1953
    _FACTORYDESC._serialized_start = 92
    _FACTORYDESC._serialized_end = 197
    _COLLECTIONFACTORYDESC._serialized_start = 199
    _COLLECTIONFACTORYDESC._serialized_end = 314
    _CREATE._serialized_start = 317
    _CREATE._serialized_end = 475
    _COLLECTIONPROXYDESC._serialized_start = 477
    _COLLECTIONPROXYDESC._serialized_end = 548
    _SETTIMESTEP._serialized_start = 550
    _SETTIMESTEP._serialized_end = 624
    _LIGHTDESC._serialized_start = 627
    _LIGHTDESC._serialized_end = 835
    _SETLIGHT._serialized_start = 837
    _SETLIGHT._serialized_end = 956
    _SETVIEWPROJECTION._serialized_start = 958
    _SETVIEWPROJECTION._serialized_end = 1057
    _PLAYSOUND._serialized_start = 1060
    _PLAYSOUND._serialized_end = 1216
    _STOPSOUND._serialized_start = 1218
    _STOPSOUND._serialized_end = 1258
    _PAUSESOUND._serialized_start = 1260
    _PAUSESOUND._serialized_end = 1293
    _SOUNDEVENT._serialized_start = 1295
    _SOUNDEVENT._serialized_end = 1327
    _SETGAIN._serialized_start = 1329
    _SETGAIN._serialized_end = 1355
    _SETPAN._serialized_start = 1357
    _SETPAN._serialized_end = 1381
    _SETSPEED._serialized_start = 1383
    _SETSPEED._serialized_end = 1411
    _PLAYPARTICLEFX._serialized_start = 1413
    _PLAYPARTICLEFX._serialized_end = 1429
    _STOPPARTICLEFX._serialized_start = 1431
    _STOPPARTICLEFX._serialized_end = 1479
    _SETCONSTANTPARTICLEFX._serialized_start = 1481
    _SETCONSTANTPARTICLEFX._serialized_end = 1601
    _RESETCONSTANTPARTICLEFX._serialized_start = 1603
    _RESETCONSTANTPARTICLEFX._serialized_end = 1667
    _SETCONSTANT._serialized_start = 1669
    _SETCONSTANT._serialized_end = 1757
    _RESETCONSTANT._serialized_start = 1759
    _RESETCONSTANT._serialized_end = 1793
    _SETSCALE._serialized_start = 1795
    _SETSCALE._serialized_end = 1843



"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from defoldsdk.ddf import ddf_extensions_pb2 as ddf_dot_ddf__extensions__pb2
from defoldsdk.ddf import ddf_math_pb2 as ddf_dot_ddf__math__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18gamesys/buffer_ddf.proto\x12\x0bdmBufferDDF\x1a\x18ddf/ddf_extensions.proto\x1a\x12ddf/ddf_math.proto"\xab\x01\n\nStreamDesc\x12\x0c\n\x04name\x18\x01 \x02(\t\x12*\n\nvalue_type\x18\x02 \x02(\x0e2\x16.dmBufferDDF.ValueType\x12\x13\n\x0bvalue_count\x18\x03 \x02(\r\x12\n\n\x02ui\x18\x04 \x03(\r\x12\t\n\x01i\x18\x05 \x03(\x05\x12\x0c\n\x04ui64\x18\x06 \x03(\x04\x12\x0b\n\x03i64\x18\x07 \x03(\x03\x12\t\n\x01f\x18\x08 \x03(\x02\x12\x11\n\tname_hash\x18\t \x02(\x04"6\n\nBufferDesc\x12(\n\x07streams\x18\x01 \x03(\x0b2\x17.dmBufferDDF.StreamDesc*\xd5\x01\n\tValueType\x12\x14\n\x10VALUE_TYPE_UINT8\x10\x00\x12\x15\n\x11VALUE_TYPE_UINT16\x10\x01\x12\x15\n\x11VALUE_TYPE_UINT32\x10\x02\x12\x15\n\x11VALUE_TYPE_UINT64\x10\x03\x12\x13\n\x0fVALUE_TYPE_INT8\x10\x04\x12\x14\n\x10VALUE_TYPE_INT16\x10\x05\x12\x14\n\x10VALUE_TYPE_INT32\x10\x06\x12\x14\n\x10VALUE_TYPE_INT64\x10\x07\x12\x16\n\x12VALUE_TYPE_FLOAT32\x10\x08B\'\n\x18com.dynamo.gamesys.protoB\x0bBufferProto')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gamesys.buffer_ddf_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'\n\x18com.dynamo.gamesys.protoB\x0bBufferProto'
    _VALUETYPE._serialized_start = 318
    _VALUETYPE._serialized_end = 531
    _STREAMDESC._serialized_start = 88
    _STREAMDESC._serialized_end = 259
    _BUFFERDESC._serialized_start = 261
    _BUFFERDESC._serialized_end = 315



"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from defoldsdk.ddf import ddf_extensions_pb2 as ddf_dot_ddf__extensions__pb2
from defoldsdk.ddf import ddf_math_pb2 as ddf_dot_ddf__math__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17gamesys/sound_ddf.proto\x12\ndmSoundDDF\x1a\x18ddf/ddf_extensions.proto\x1a\x12ddf/ddf_math.proto"\x94\x01\n\tSoundDesc\x12\x13\n\x05sound\x18\x01 \x02(\tB\x04\xa0\xbb\x18\x01\x12\x12\n\x07looping\x18\x02 \x01(\x05:\x010\x12\x15\n\x05group\x18\x03 \x01(\t:\x06master\x12\x0f\n\x04gain\x18\x04 \x01(\x02:\x011\x12\x0e\n\x03pan\x18\x05 \x01(\x02:\x010\x12\x10\n\x05speed\x18\x06 \x01(\x02:\x011\x12\x14\n\tloopcount\x18\x07 \x01(\x05:\x010B!\n\x18com.dynamo.gamesys.protoB\x05Sound')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gamesys.sound_ddf_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'\n\x18com.dynamo.gamesys.protoB\x05Sound'
    _SOUNDDESC.fields_by_name['sound']._options = None
    _SOUNDDESC.fields_by_name['sound']._serialized_options = b'\xa0\xbb\x18\x01'
    _SOUNDDESC._serialized_start = 86
    _SOUNDDESC._serialized_end = 234



from .sprite_ddf_pb2 import *
from .texture_set_ddf_pb2 import *
from .label_ddf_pb2 import *
from .gui_ddf_pb2 import *
from .gamesys_ddf_pb2 import *
from .sound_ddf_pb2 import *
from .mesh_ddf_pb2 import *
from .model_ddf_pb2 import *
from .tile_ddf_pb2 import *
from .buffer_ddf_pb2 import *
from .atlas_ddf_pb2 import *
from .camera_ddf_pb2 import *
from .physics_ddf_pb2 import *



"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from defoldsdk.ddf import ddf_extensions_pb2 as ddf_dot_ddf__extensions__pb2
from defoldsdk.ddf import ddf_math_pb2 as ddf_dot_ddf__math__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bresource/resource_ddf.proto\x12\rdmResourceDDF\x1a\x18ddf/ddf_extensions.proto\x1a\x12ddf/ddf_math.proto"\x1b\n\x06Reload\x12\x11\n\tresources\x18\x01 \x03(\tB%\n\x19com.dynamo.resource.protoB\x08Resource')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'resource.resource_ddf_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'\n\x19com.dynamo.resource.protoB\x08Resource'
    _RELOAD._serialized_start = 92
    _RELOAD._serialized_end = 119



"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18ddf/ddf_extensions.proto\x1a google/protobuf/descriptor.proto:0\n\x05alias\x12\x1f.google.protobuf.MessageOptions\x18\xd0\x86\x03 \x01(\t:7\n\x0cstruct_align\x12\x1f.google.protobuf.MessageOptions\x18\xd3\x86\x03 \x01(\x08:1\n\x08resource\x12\x1d.google.protobuf.FieldOptions\x18\xb4\x87\x03 \x01(\x08:5\n\x0cruntime_only\x12\x1d.google.protobuf.FieldOptions\x18\xb5\x87\x03 \x01(\x08:4\n\x0bfield_align\x12\x1d.google.protobuf.FieldOptions\x18\xd4\x86\x03 \x01(\x08:8\n\x0bdisplayName\x12!.google.protobuf.EnumValueOptions\x18\x98\x88\x03 \x01(\t:5\n\rddf_namespace\x12\x1c.google.protobuf.FileOptions\x18\xd1\x86\x03 \x01(\t:4\n\x0cddf_includes\x12\x1c.google.protobuf.FileOptions\x18\xd2\x86\x03 \x01(\tB!\n\x10com.dynamo.protoB\rDdfExtensions')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ddf.ddf_extensions_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(alias)
    google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(struct_align)
    google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(resource)
    google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(runtime_only)
    google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(field_align)
    google_dot_protobuf_dot_descriptor__pb2.EnumValueOptions.RegisterExtension(displayName)
    google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(ddf_namespace)
    google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(ddf_includes)
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'\n\x10com.dynamo.protoB\rDdfExtensions'



from setuptools import setup, find_packages
import os 



setup(
    name="defoldsdk",
    version="1.3.7",
    author="issam Mhadhbi",
    author_email="mhadhbixissam@gmail.com",
    description="Defold protobuff compiled to python package",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/MhadhbiXissam/defoldsdk.git",
    packages=find_packages(),
    install_requires=[
        "protobuf","requests"
    ],
    project_urls={
        "Documentation": "https://github.com/MhadhbiXissam/defoldsdk/tree/main/doc",
        "Source": "https://github.com/MhadhbiXissam/defoldsdk.git"
    } , 
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
    ],
    python_requires=">=3.8",
)



"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bscript/lua_source_ddf.proto\x12\x08dmLuaDDF"x\n\tLuaSource\x12\x0e\n\x06script\x18\x01 \x01(\x0c\x12\x10\n\x08filename\x18\x02 \x02(\t\x12\x10\n\x08bytecode\x18\x03 \x01(\x0c\x12\r\n\x05delta\x18\x05 \x01(\x0c\x12\x13\n\x0bbytecode_32\x18\x06 \x01(\x0c\x12\x13\n\x0bbytecode_64\x18\x04 \x01(\x0cB\x1e\n\x17com.dynamo.script.protoB\x03Lua')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'script.lua_source_ddf_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'\n\x17com.dynamo.script.protoB\x03Lua'
    _LUASOURCE._serialized_start = 41
    _LUASOURCE._serialized_end = 161



"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from defoldsdk.ddf import ddf_extensions_pb2 as ddf_dot_ddf__extensions__pb2
from defoldsdk.ddf import ddf_math_pb2 as ddf_dot_ddf__math__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16gamesys/tile_ddf.proto\x12\x0fdmGameSystemDDF\x1a\x18ddf/ddf_extensions.proto\x1a\x12ddf/ddf_math.proto"O\n\nConvexHull\x12\x10\n\x05index\x18\x01 \x02(\r:\x010\x12\x10\n\x05count\x18\x02 \x02(\r:\x010\x12\x1d\n\x0fcollision_group\x18\x03 \x02(\t:\x04tile"2\n\x03Cue\x12\n\n\x02id\x18\x01 \x02(\t\x12\r\n\x05frame\x18\x02 \x02(\r\x12\x10\n\x05value\x18\x03 \x01(\x02:\x010"\xec\x01\n\tAnimation\x12\n\n\x02id\x18\x01 \x02(\t\x12\x12\n\nstart_tile\x18\x02 \x02(\r\x12\x10\n\x08end_tile\x18\x03 \x02(\r\x12B\n\x08playback\x18\x04 \x01(\x0e2\x19.dmGameSystemDDF.Playback:\x15PLAYBACK_ONCE_FORWARD\x12\x0f\n\x03fps\x18\x05 \x01(\r:\x0230\x12\x1a\n\x0fflip_horizontal\x18\x06 \x01(\r:\x010\x12\x18\n\rflip_vertical\x18\x07 \x01(\r:\x010\x12"\n\x04cues\x18\x08 \x03(\x0b2\x14.dmGameSystemDDF.Cue"\xdd\x03\n\x07TileSet\x12\x13\n\x05image\x18\x01 \x02(\tB\x04\xa0\xbb\x18\x01\x12\x15\n\ntile_width\x18\x02 \x02(\r:\x010\x12\x16\n\x0btile_height\x18\x03 \x02(\r:\x010\x12\x16\n\x0btile_margin\x18\x04 \x01(\r:\x010\x12\x17\n\x0ctile_spacing\x18\x05 \x01(\r:\x010\x12\x17\n\tcollision\x18\x06 \x01(\tB\x04\xa0\xbb\x18\x01\x12\x1a\n\x0cmaterial_tag\x18\x07 \x01(\t:\x04tile\x121\n\x0cconvex_hulls\x18\x08 \x03(\x0b2\x1b.dmGameSystemDDF.ConvexHull\x12 \n\x12convex_hull_points\x18\t \x03(\x02B\x04\xa8\xbb\x18\x01\x12\x18\n\x10collision_groups\x18\n \x03(\t\x12.\n\nanimations\x18\x0b \x03(\x0b2\x1a.dmGameSystemDDF.Animation\x12\x1a\n\x0fextrude_borders\x18\x0c \x01(\r:\x010\x12\x18\n\rinner_padding\x18\r \x01(\r:\x010\x12S\n\x10sprite_trim_mode\x18\x0e \x01(\x0e2#.dmGameSystemDDF.SpriteTrimmingMode:\x14SPRITE_TRIM_MODE_OFF"r\n\x08TileCell\x12\x0c\n\x01x\x18\x01 \x02(\x05:\x010\x12\x0c\n\x01y\x18\x02 \x02(\x05:\x010\x12\x0f\n\x04tile\x18\x03 \x02(\r:\x010\x12\x11\n\x06h_flip\x18\x04 \x01(\r:\x010\x12\x11\n\x06v_flip\x18\x05 \x01(\r:\x010\x12\x13\n\x08rotate90\x18\x06 \x01(\r:\x010"\x87\x01\n\tTileLayer\x12\x12\n\x02id\x18\x01 \x02(\t:\x06layer1\x12\x0c\n\x01z\x18\x02 \x02(\x02:\x010\x12\x15\n\nis_visible\x18\x03 \x01(\r:\x011\x12\x18\n\x07id_hash\x18\x04 \x01(\x04:\x010B\x04\xa8\xbb\x18\x01\x12\'\n\x04cell\x18\x06 \x03(\x0b2\x19.dmGameSystemDDF.TileCell"\xa0\x03\n\x08TileGrid\x12\x16\n\x08tile_set\x18\x01 \x02(\tB\x04\xa0\xbb\x18\x01\x12*\n\x06layers\x18\x02 \x03(\x0b2\x1a.dmGameSystemDDF.TileLayer\x12=\n\x08material\x18\x03 \x01(\t:%/builtins/materials/tile_map.materialB\x04\xa0\xbb\x18\x01\x12I\n\nblend_mode\x18\x04 \x01(\x0e2#.dmGameSystemDDF.TileGrid.BlendMode:\x10BLEND_MODE_ALPHA"\xc5\x01\n\tBlendMode\x12\x1f\n\x10BLEND_MODE_ALPHA\x10\x00\x1a\t\xc2\xc1\x18\x05Alpha\x12\x1b\n\x0eBLEND_MODE_ADD\x10\x01\x1a\x07\xc2\xc1\x18\x03Add\x124\n\x14BLEND_MODE_ADD_ALPHA\x10\x02\x1a\x1a\xc2\xc1\x18\x16Add Alpha (Deprecated)\x12!\n\x0fBLEND_MODE_MULT\x10\x03\x1a\x0c\xc2\xc1\x18\x08Multiply\x12!\n\x11BLEND_MODE_SCREEN\x10\x04\x1a\n\xc2\xc1\x18\x06Screen"M\n\x12SetConstantTileMap\x12\x11\n\tname_hash\x18\x01 \x02(\x04\x12$\n\x05value\x18\x02 \x02(\x0b2\x0f.dmMath.Vector4B\x04\xa0\xb5\x18\x01")\n\x14ResetConstantTileMap\x12\x11\n\tname_hash\x18\x01 \x02(\x04*\xbf\x02\n\x08Playback\x12\x1b\n\rPLAYBACK_NONE\x10\x00\x1a\x08\xc2\xc1\x18\x04None\x12+\n\x15PLAYBACK_ONCE_FORWARD\x10\x01\x1a\x10\xc2\xc1\x18\x0cOnce Forward\x12-\n\x16PLAYBACK_ONCE_BACKWARD\x10\x02\x1a\x11\xc2\xc1\x18\rOnce Backward\x12.\n\x16PLAYBACK_ONCE_PINGPONG\x10\x06\x1a\x12\xc2\xc1\x18\x0eOnce Ping Pong\x12+\n\x15PLAYBACK_LOOP_FORWARD\x10\x03\x1a\x10\xc2\xc1\x18\x0cLoop Forward\x12-\n\x16PLAYBACK_LOOP_BACKWARD\x10\x04\x1a\x11\xc2\xc1\x18\rLoop Backward\x12.\n\x16PLAYBACK_LOOP_PINGPONG\x10\x05\x1a\x12\xc2\xc1\x18\x0eLoop Ping Pong*\xa7\x02\n\x12SpriteTrimmingMode\x12!\n\x14SPRITE_TRIM_MODE_OFF\x10\x00\x1a\x07\xc2\xc1\x18\x03Off\x12&\n\x12SPRITE_TRIM_MODE_4\x10\x04\x1a\x0e\xc2\xc1\x18\n4 Vertices\x12&\n\x12SPRITE_TRIM_MODE_5\x10\x05\x1a\x0e\xc2\xc1\x18\n5 Vertices\x12&\n\x12SPRITE_TRIM_MODE_6\x10\x06\x1a\x0e\xc2\xc1\x18\n6 Vertices\x12&\n\x12SPRITE_TRIM_MODE_7\x10\x07\x1a\x0e\xc2\xc1\x18\n7 Vertices\x12&\n\x12SPRITE_TRIM_MODE_8\x10\x08\x1a\x0e\xc2\xc1\x18\n8 Vertices\x12&\n\x14SPRITE_TRIM_POLYGONS\x10\t\x1a\x0c\xc2\xc1\x18\x08PolygonsB \n\x18com.dynamo.gamesys.protoB\x04Tile')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gamesys.tile_ddf_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'\n\x18com.dynamo.gamesys.protoB\x04Tile'
    _PLAYBACK.values_by_name['PLAYBACK_NONE']._options = None
    _PLAYBACK.values_by_name['PLAYBACK_NONE']._serialized_options = b'\xc2\xc1\x18\x04None'
    _PLAYBACK.values_by_name['PLAYBACK_ONCE_FORWARD']._options = None
    _PLAYBACK.values_by_name['PLAYBACK_ONCE_FORWARD']._serialized_options = b'\xc2\xc1\x18\x0cOnce Forward'
    _PLAYBACK.values_by_name['PLAYBACK_ONCE_BACKWARD']._options = None
    _PLAYBACK.values_by_name['PLAYBACK_ONCE_BACKWARD']._serialized_options = b'\xc2\xc1\x18\rOnce Backward'
    _PLAYBACK.values_by_name['PLAYBACK_ONCE_PINGPONG']._options = None
    _PLAYBACK.values_by_name['PLAYBACK_ONCE_PINGPONG']._serialized_options = b'\xc2\xc1\x18\x0eOnce Ping Pong'
    _PLAYBACK.values_by_name['PLAYBACK_LOOP_FORWARD']._options = None
    _PLAYBACK.values_by_name['PLAYBACK_LOOP_FORWARD']._serialized_options = b'\xc2\xc1\x18\x0cLoop Forward'
    _PLAYBACK.values_by_name['PLAYBACK_LOOP_BACKWARD']._options = None
    _PLAYBACK.values_by_name['PLAYBACK_LOOP_BACKWARD']._serialized_options = b'\xc2\xc1\x18\rLoop Backward'
    _PLAYBACK.values_by_name['PLAYBACK_LOOP_PINGPONG']._options = None
    _PLAYBACK.values_by_name['PLAYBACK_LOOP_PINGPONG']._serialized_options = b'\xc2\xc1\x18\x0eLoop Ping Pong'
    _SPRITETRIMMINGMODE.values_by_name['SPRITE_TRIM_MODE_OFF']._options = None
    _SPRITETRIMMINGMODE.values_by_name['SPRITE_TRIM_MODE_OFF']._serialized_options = b'\xc2\xc1\x18\x03Off'
    _SPRITETRIMMINGMODE.values_by_name['SPRITE_TRIM_MODE_4']._options = None
    _SPRITETRIMMINGMODE.values_by_name['SPRITE_TRIM_MODE_4']._serialized_options = b'\xc2\xc1\x18\n4 Vertices'
    _SPRITETRIMMINGMODE.values_by_name['SPRITE_TRIM_MODE_5']._options = None
    _SPRITETRIMMINGMODE.values_by_name['SPRITE_TRIM_MODE_5']._serialized_options = b'\xc2\xc1\x18\n5 Vertices'
    _SPRITETRIMMINGMODE.values_by_name['SPRITE_TRIM_MODE_6']._options = None
    _SPRITETRIMMINGMODE.values_by_name['SPRITE_TRIM_MODE_6']._serialized_options = b'\xc2\xc1\x18\n6 Vertices'
    _SPRITETRIMMINGMODE.values_by_name['SPRITE_TRIM_MODE_7']._options = None
    _SPRITETRIMMINGMODE.values_by_name['SPRITE_TRIM_MODE_7']._serialized_options = b'\xc2\xc1\x18\n7 Vertices'
    _SPRITETRIMMINGMODE.values_by_name['SPRITE_TRIM_MODE_8']._options = None
    _SPRITETRIMMINGMODE.values_by_name['SPRITE_TRIM_MODE_8']._serialized_options = b'\xc2\xc1\x18\n8 Vertices'
    _SPRITETRIMMINGMODE.values_by_name['SPRITE_TRIM_POLYGONS']._options = None
    _SPRITETRIMMINGMODE.values_by_name['SPRITE_TRIM_POLYGONS']._serialized_options = b'\xc2\xc1\x18\x08Polygons'
    _TILESET.fields_by_name['image']._options = None
    _TILESET.fields_by_name['image']._serialized_options = b'\xa0\xbb\x18\x01'
    _TILESET.fields_by_name['collision']._options = None
    _TILESET.fields_by_name['collision']._serialized_options = b'\xa0\xbb\x18\x01'
    _TILESET.fields_by_name['convex_hull_points']._options = None
    _TILESET.fields_by_name['convex_hull_points']._serialized_options = b'\xa8\xbb\x18\x01'
    _TILELAYER.fields_by_name['id_hash']._options = None
    _TILELAYER.fields_by_name['id_hash']._serialized_options = b'\xa8\xbb\x18\x01'
    _TILEGRID_BLENDMODE.values_by_name['BLEND_MODE_ALPHA']._options = None
    _TILEGRID_BLENDMODE.values_by_name['BLEND_MODE_ALPHA']._serialized_options = b'\xc2\xc1\x18\x05Alpha'
    _TILEGRID_BLENDMODE.values_by_name['BLEND_MODE_ADD']._options = None
    _TILEGRID_BLENDMODE.values_by_name['BLEND_MODE_ADD']._serialized_options = b'\xc2\xc1\x18\x03Add'
    _TILEGRID_BLENDMODE.values_by_name['BLEND_MODE_ADD_ALPHA']._options = None
    _TILEGRID_BLENDMODE.values_by_name['BLEND_MODE_ADD_ALPHA']._serialized_options = b'\xc2\xc1\x18\x16Add Alpha (Deprecated)'
    _TILEGRID_BLENDMODE.values_by_name['BLEND_MODE_MULT']._options = None
    _TILEGRID_BLENDMODE.values_by_name['BLEND_MODE_MULT']._serialized_options = b'\xc2\xc1\x18\x08Multiply'
    _TILEGRID_BLENDMODE.values_by_name['BLEND_MODE_SCREEN']._options = None
    _TILEGRID_BLENDMODE.values_by_name['BLEND_MODE_SCREEN']._serialized_options = b'\xc2\xc1\x18\x06Screen'
    _TILEGRID.fields_by_name['tile_set']._options = None
    _TILEGRID.fields_by_name['tile_set']._serialized_options = b'\xa0\xbb\x18\x01'
    _TILEGRID.fields_by_name['material']._options = None
    _TILEGRID.fields_by_name['material']._serialized_options = b'\xa0\xbb\x18\x01'
    _SETCONSTANTTILEMAP.fields_by_name['value']._options = None
    _SETCONSTANTTILEMAP.fields_by_name['value']._serialized_options = b'\xa0\xb5\x18\x01'
    _PLAYBACK._serialized_start = 1737
    _PLAYBACK._serialized_end = 2056
    _SPRITETRIMMINGMODE._serialized_start = 2059
    _SPRITETRIMMINGMODE._serialized_end = 2354
    _CONVEXHULL._serialized_start = 89
    _CONVEXHULL._serialized_end = 168
    _CUE._serialized_start = 170
    _CUE._serialized_end = 220
    _ANIMATION._serialized_start = 223
    _ANIMATION._serialized_end = 459
    _TILESET._serialized_start = 462
    _TILESET._serialized_end = 939
    _TILECELL._serialized_start = 941
    _TILECELL._serialized_end = 1055
    _TILELAYER._serialized_start = 1058
    _TILELAYER._serialized_end = 1193
    _TILEGRID._serialized_start = 1196
    _TILEGRID._serialized_end = 1612
    _TILEGRID_BLENDMODE._serialized_start = 1415
    _TILEGRID_BLENDMODE._serialized_end = 1612
    _SETCONSTANTTILEMAP._serialized_start = 1614
    _SETCONSTANTTILEMAP._serialized_end = 1691
    _RESETCONSTANTTILEMAP._serialized_start = 1693
    _RESETCONSTANTTILEMAP._serialized_end = 1734



"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from defoldsdk.ddf import ddf_extensions_pb2 as ddf_dot_ddf__extensions__pb2
from defoldsdk.ddf import ddf_math_pb2 as ddf_dot_ddf__math__pb2
from defoldsdk.gameobject import lua_ddf_pb2 as gameobject_dot_lua__ddf__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17engine/engine_ddf.proto\x12\x0bdmEngineDDF\x1a\x18ddf/ddf_extensions.proto\x1a\x12ddf/ddf_math.proto\x1a\x18gameobject/lua_ddf.proto"\t\n\x07HideApp"0\n\tRunScript\x12#\n\x06module\x18\x01 \x02(\x0b2\x13.dmLuaDDF.LuaModuleB!\n\x17com.dynamo.engine.protoB\x06Engine')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'engine.engine_ddf_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'\n\x17com.dynamo.engine.protoB\x06Engine'
    _HIDEAPP._serialized_start = 112
    _HIDEAPP._serialized_end = 121
    _RUNSCRIPT._serialized_start = 123
    _RUNSCRIPT._serialized_end = 171



"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from defoldsdk.ddf import ddf_extensions_pb2 as ddf_dot_ddf__extensions__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17script/ddf_script.proto\x12\x0bdmScriptDDF\x1a\x18ddf/ddf_extensions.proto"6\n\x06LuaRef\x12\x0e\n\x03ref\x18\x01 \x02(\x05:\x010\x12\x1c\n\x11context_table_ref\x18\x02 \x02(\x05:\x010B\'\n\x1acom.dynamo.ddfscript.protoB\tDdfScript')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'script.ddf_script_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'\n\x1acom.dynamo.ddfscript.protoB\tDdfScript'
    _LUAREF._serialized_start = 66
    _LUAREF._serialized_end = 120



"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from defoldsdk.ddf import ddf_extensions_pb2 as ddf_dot_ddf__extensions__pb2
from defoldsdk.ddf import ddf_math_pb2 as ddf_dot_ddf__math__pb2
from defoldsdk.graphics import graphics_ddf_pb2 as graphics_dot_graphics__ddf__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19render/material_ddf.proto\x12\x0bdmRenderDDF\x1a\x18ddf/ddf_extensions.proto\x1a\x12ddf/ddf_math.proto\x1a\x1bgraphics/graphics_ddf.proto"\xd1\x10\n\x0cMaterialDesc\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x0c\n\x04tags\x18\x02 \x03(\t\x12\x1c\n\x0evertex_program\x18\x03 \x02(\tB\x04\xa0\xbb\x18\x01\x12\x1e\n\x10fragment_program\x18\x04 \x02(\tB\x04\xa0\xbb\x18\x01\x12;\n\x0cvertex_space\x18\x05 \x01(\x0e2%.dmRenderDDF.MaterialDesc.VertexSpace\x12<\n\x10vertex_constants\x18\x06 \x03(\x0b2".dmRenderDDF.MaterialDesc.Constant\x12>\n\x12fragment_constants\x18\x07 \x03(\x0b2".dmRenderDDF.MaterialDesc.Constant\x12\x10\n\x08textures\x18\x08 \x03(\t\x123\n\x08samplers\x18\t \x03(\x0b2!.dmRenderDDF.MaterialDesc.Sampler\x12\x19\n\x0emax_page_count\x18\n \x01(\r:\x010\x12/\n\nattributes\x18\x0b \x03(\x0b2\x1b.dmGraphics.VertexAttribute\x12\x19\n\x07program\x18\x0c \x01(\tB\x08\xa0\xbb\x18\x01\xa8\xbb\x18\x01\x12E\n\x0epbr_parameters\x18\r \x01(\x0b2\'.dmRenderDDF.MaterialDesc.PbrParametersB\x04\xa8\xbb\x18\x01\x1an\n\x08Constant\x12\x0c\n\x04name\x18\x01 \x02(\t\x124\n\x04type\x18\x02 \x02(\x0e2&.dmRenderDDF.MaterialDesc.ConstantType\x12\x1e\n\x05value\x18\x03 \x03(\x0b2\x0f.dmMath.Vector4\x1a\x9f\x02\n\rPbrParameters\x12\x16\n\x0ehas_parameters\x18\x01 \x01(\x08\x12\x1e\n\x16has_metallic_roughness\x18\x02 \x01(\x08\x12\x1f\n\x17has_specular_glossiness\x18\x03 \x01(\x08\x12\x15\n\rhas_clearcoat\x18\x04 \x01(\x08\x12\x18\n\x10has_transmission\x18\x05 \x01(\x08\x12\x0f\n\x07has_ior\x18\x06 \x01(\x08\x12\x14\n\x0chas_specular\x18\x07 \x01(\x08\x12\x12\n\nhas_volume\x18\x08 \x01(\x08\x12\x11\n\thas_sheen\x18\t \x01(\x08\x12\x1d\n\x15has_emissive_strength\x18\n \x01(\x08\x12\x17\n\x0fhas_iridescence\x18\x0b \x01(\x08\x1a\xe5\x02\n\x07Sampler\x12\x0c\n\x04name\x18\x01 \x02(\t\x122\n\x06wrap_u\x18\x02 \x02(\x0e2".dmRenderDDF.MaterialDesc.WrapMode\x122\n\x06wrap_v\x18\x03 \x02(\x0e2".dmRenderDDF.MaterialDesc.WrapMode\x12;\n\nfilter_min\x18\x04 \x02(\x0e2\'.dmRenderDDF.MaterialDesc.FilterModeMin\x12;\n\nfilter_mag\x18\x05 \x02(\x0e2\'.dmRenderDDF.MaterialDesc.FilterModeMag\x12\x19\n\x0emax_anisotropy\x18\x06 \x01(\x02:\x011\x12\x1f\n\x11name_indirections\x18\x07 \x03(\x04B\x04\xa8\xbb\x18\x01\x12\x15\n\x07texture\x18\x08 \x01(\tB\x04\xa0\xbb\x18\x01\x12\x17\n\tname_hash\x18\t \x01(\x04B\x04\xa8\xbb\x18\x01"\xa4\x02\n\x0cConstantType\x12\x16\n\x12CONSTANT_TYPE_USER\x10\x00\x12\x1a\n\x16CONSTANT_TYPE_VIEWPROJ\x10\x01\x12\x17\n\x13CONSTANT_TYPE_WORLD\x10\x02\x12\x19\n\x15CONSTANT_TYPE_TEXTURE\x10\x03\x12\x16\n\x12CONSTANT_TYPE_VIEW\x10\x04\x12\x1c\n\x18CONSTANT_TYPE_PROJECTION\x10\x05\x12\x18\n\x14CONSTANT_TYPE_NORMAL\x10\x06\x12\x1b\n\x17CONSTANT_TYPE_WORLDVIEW\x10\x07\x12\x1f\n\x1bCONSTANT_TYPE_WORLDVIEWPROJ\x10\x08\x12\x1e\n\x1aCONSTANT_TYPE_USER_MATRIX4\x10\t"=\n\x0bVertexSpace\x12\x16\n\x12VERTEX_SPACE_WORLD\x10\x00\x12\x16\n\x12VERTEX_SPACE_LOCAL\x10\x01"\\\n\x08WrapMode\x12\x14\n\x10WRAP_MODE_REPEAT\x10\x00\x12\x1d\n\x19WRAP_MODE_MIRRORED_REPEAT\x10\x01\x12\x1b\n\x17WRAP_MODE_CLAMP_TO_EDGE\x10\x02"\x91\x02\n\rFilterModeMin\x12\x1b\n\x17FILTER_MODE_MIN_NEAREST\x10\x00\x12\x1a\n\x16FILTER_MODE_MIN_LINEAR\x10\x01\x12*\n&FILTER_MODE_MIN_NEAREST_MIPMAP_NEAREST\x10\x02\x12)\n%FILTER_MODE_MIN_NEAREST_MIPMAP_LINEAR\x10\x03\x12)\n%FILTER_MODE_MIN_LINEAR_MIPMAP_NEAREST\x10\x04\x12(\n$FILTER_MODE_MIN_LINEAR_MIPMAP_LINEAR\x10\x05\x12\x1b\n\x17FILTER_MODE_MIN_DEFAULT\x10\x06"e\n\rFilterModeMag\x12\x1b\n\x17FILTER_MODE_MAG_NEAREST\x10\x00\x12\x1a\n\x16FILTER_MODE_MAG_LINEAR\x10\x01\x12\x1b\n\x17FILTER_MODE_MAG_DEFAULT\x10\x02B#\n\x17com.dynamo.render.protoB\x08Material')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'render.material_ddf_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'\n\x17com.dynamo.render.protoB\x08Material'
    _MATERIALDESC_SAMPLER.fields_by_name['name_indirections']._options = None
    _MATERIALDESC_SAMPLER.fields_by_name['name_indirections']._serialized_options = b'\xa8\xbb\x18\x01'
    _MATERIALDESC_SAMPLER.fields_by_name['texture']._options = None
    _MATERIALDESC_SAMPLER.fields_by_name['texture']._serialized_options = b'\xa0\xbb\x18\x01'
    _MATERIALDESC_SAMPLER.fields_by_name['name_hash']._options = None
    _MATERIALDESC_SAMPLER.fields_by_name['name_hash']._serialized_options = b'\xa8\xbb\x18\x01'
    _MATERIALDESC.fields_by_name['vertex_program']._options = None
    _MATERIALDESC.fields_by_name['vertex_program']._serialized_options = b'\xa0\xbb\x18\x01'
    _MATERIALDESC.fields_by_name['fragment_program']._options = None
    _MATERIALDESC.fields_by_name['fragment_program']._serialized_options = b'\xa0\xbb\x18\x01'
    _MATERIALDESC.fields_by_name['program']._options = None
    _MATERIALDESC.fields_by_name['program']._serialized_options = b'\xa0\xbb\x18\x01\xa8\xbb\x18\x01'
    _MATERIALDESC.fields_by_name['pbr_parameters']._options = None
    _MATERIALDESC.fields_by_name['pbr_parameters']._serialized_options = b'\xa8\xbb\x18\x01'
    _MATERIALDESC._serialized_start = 118
    _MATERIALDESC._serialized_end = 2247
    _MATERIALDESC_CONSTANT._serialized_start = 656
    _MATERIALDESC_CONSTANT._serialized_end = 766
    _MATERIALDESC_PBRPARAMETERS._serialized_start = 769
    _MATERIALDESC_PBRPARAMETERS._serialized_end = 1056
    _MATERIALDESC_SAMPLER._serialized_start = 1059
    _MATERIALDESC_SAMPLER._serialized_end = 1416
    _MATERIALDESC_CONSTANTTYPE._serialized_start = 1419
    _MATERIALDESC_CONSTANTTYPE._serialized_end = 1711
    _MATERIALDESC_VERTEXSPACE._serialized_start = 1713
    _MATERIALDESC_VERTEXSPACE._serialized_end = 1774
    _MATERIALDESC_WRAPMODE._serialized_start = 1776
    _MATERIALDESC_WRAPMODE._serialized_end = 1868
    _MATERIALDESC_FILTERMODEMIN._serialized_start = 1871
    _MATERIALDESC_FILTERMODEMIN._serialized_end = 2144
    _MATERIALDESC_FILTERMODEMAG._serialized_start = 2146
    _MATERIALDESC_FILTERMODEMAG._serialized_end = 2247
